;;; name-this-color.el --- Match RGB codes to names easily and precisely -*- lexical-binding: t -*-

;; Copyright (c) 2015, Nikola Knezevic All rights reserved.

;; Authors: Nikola Knezevic <knl@soba143.net>
;; Created: 2015-10-10
;; Package-Version: 0.3.0
;; Package-Revision: 0.3.0-0-ge37cd1291d5d
;; URL: https://github.com/knl/name-this-color.el
;; Package-Requires: ((emacs "24") (cl-lib "0.5") (dash "2.11.0"))
;; Keywords: lisp, color, hex, rgb, shade, name

;; This file is not part of GNU Emacs.

;; Simplified BSD License
;;
;; Redistribution and use in source and binary forms, with or without modification,
;; are permitted provided that the following conditions are met:
;;
;; 1. Redistributions of source code must retain the above copyright notice, this
;; list of conditions and the following disclaimer.
;;
;; 2. Redistributions in binary form must reproduce the above copyright notice,
;; this list of conditions and the following disclaimer in the documentation and/or
;; other materials provided with the distribution.
;;
;; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
;; WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
;; DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
;; ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
;; (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
;; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
;; ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
;; (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
;; SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;;

;;; Commentary:
;;
;; This package provides functions for getting a color's name based on hex RGB code.
;;
;; Please see "README.org" for detailed instructions.
;; Documentation is also available at https://github.com/knl/name-this-color.el
;;
;; Color names and shades are taken from 'Name that Color JavaScript' by Chirag
;; Mehta (http://chir.ag/projects/ntc/) and 'Color Name & Hue'
;; (http://www.color-blindness.com/color-name-hue/) by Colblindor.
;;
;;
;;; Code:

(require 'cl-lib)
(require 'color)
(require 'dash)

(cl-defstruct (ntc--struct (:type vector :named))
  (code :read-only t)
  (name :read-only t)
  (shade :read-only t))

;; source
;; http://www.color-blindness.com/color-name-hue-tool/js/ntc.js
;; this list covers around 0.025177 of the whole RGB space
(defconst ntc--colors (list
                      (make-ntc--struct :code "#35312C" :name "Acadia" :shade "Brown")
                      (make-ntc--struct :code "#75AA94" :name "Acapulco" :shade "Green")
                      (make-ntc--struct :code "#C0E8D5" :name "Aero Blue" :shade "Green")
                      (make-ntc--struct :code "#745085" :name "Affair" :shade "Violet")
                      (make-ntc--struct :code "#905E26" :name "Afghan Tan" :shade "Yellow")
                      (make-ntc--struct :code "#5D8AA8" :name "Air Force Blue" :shade "Blue")
                      (make-ntc--struct :code "#BEB29A" :name "Akaroa" :shade "Yellow")
                      (make-ntc--struct :code "#F2F0E6" :name "Alabaster" :shade "Grey")
                      (make-ntc--struct :code "#E1DACB" :name "Albescent White" :shade "Yellow")
                      (make-ntc--struct :code "#954E2C" :name "Alert Tan" :shade "Orange")
                      (make-ntc--struct :code "#F0F8FF" :name "Alice Blue" :shade "Blue")
                      (make-ntc--struct :code "#E32636" :name "Alizarin" :shade "Red")
                      (make-ntc--struct :code "#1F6A7D" :name "Allports" :shade "Blue")
                      (make-ntc--struct :code "#EED9C4" :name "Almond" :shade "Yellow")
                      (make-ntc--struct :code "#9A8678" :name "Almond Frost" :shade "Brown")
                      (make-ntc--struct :code "#AD8A3B" :name "Alpine" :shade "Yellow")
                      (make-ntc--struct :code "#CDC6C5" :name "Alto" :shade "Grey")
                      (make-ntc--struct :code "#848789" :name "Aluminium" :shade "Grey")
                      (make-ntc--struct :code "#E52B50" :name "Amaranth" :shade "Red")
                      (make-ntc--struct :code "#387B54" :name "Amazon" :shade "Green")
                      (make-ntc--struct :code "#FFBF00" :name "Amber" :shade "Yellow")
                      (make-ntc--struct :code "#8A7D72" :name "Americano" :shade "Brown")
                      (make-ntc--struct :code "#9966CC" :name "Amethyst" :shade "Violet")
                      (make-ntc--struct :code "#95879C" :name "Amethyst Smoke" :shade "Violet")
                      (make-ntc--struct :code "#F5E6EA" :name "Amour" :shade "Violet")
                      (make-ntc--struct :code "#7D9D72" :name "Amulet" :shade "Green")
                      (make-ntc--struct :code "#8CCEEA" :name "Anakiwa" :shade "Blue")
                      (make-ntc--struct :code "#6C461F" :name "Antique Brass" :shade "Orange")
                      (make-ntc--struct :code "#FAEBD7" :name "Antique White" :shade "White")
                      (make-ntc--struct :code "#C68E3F" :name "Anzac" :shade "Yellow")
                      (make-ntc--struct :code "#D3A95C" :name "Apache" :shade "Yellow")
                      (make-ntc--struct :code "#66B348" :name "Apple" :shade "Green")
                      (make-ntc--struct :code "#A95249" :name "Apple Blossom" :shade "Red")
                      (make-ntc--struct :code "#DEEADC" :name "Apple Green" :shade "Green")
                      (make-ntc--struct :code "#FBCEB1" :name "Apricot" :shade "Orange")
                      (make-ntc--struct :code "#F7F0DB" :name "Apricot White" :shade "Yellow")
                      (make-ntc--struct :code "#00FFFF" :name "Aqua" :shade "Blue")
                      (make-ntc--struct :code "#D9DDD5" :name "Aqua Haze" :shade "Grey")
                      (make-ntc--struct :code "#E8F3E8" :name "Aqua Spring" :shade "Green")
                      (make-ntc--struct :code "#DBE4DC" :name "Aqua Squeeze" :shade "Grey")
                      (make-ntc--struct :code "#7FFFD4" :name "Aquamarine" :shade "Blue")
                      (make-ntc--struct :code "#274A5D" :name "Arapawa" :shade "Blue")
                      (make-ntc--struct :code "#484A46" :name "Armadillo" :shade "Grey")
                      (make-ntc--struct :code "#4B5320" :name "Army green" :shade "Green")
                      (make-ntc--struct :code "#827A67" :name "Arrowtown" :shade "Yellow")
                      (make-ntc--struct :code "#3B444B" :name "Arsenic" :shade "Grey")
                      (make-ntc--struct :code "#BEBAA7" :name "Ash" :shade "Green")
                      (make-ntc--struct :code "#7BA05B" :name "Asparagus" :shade "Green")
                      (make-ntc--struct :code "#EDD5A6" :name "Astra" :shade "Yellow")
                      (make-ntc--struct :code "#376F89" :name "Astral" :shade "Blue")
                      (make-ntc--struct :code "#445172" :name "Astronaut" :shade "Blue")
                      (make-ntc--struct :code "#214559" :name "Astronaut Blue" :shade "Blue")
                      (make-ntc--struct :code "#DCDDDD" :name "Athens Grey" :shade "Grey")
                      (make-ntc--struct :code "#D5CBB2" :name "Aths Special" :shade "Yellow")
                      (make-ntc--struct :code "#9CD03B" :name "Atlantis" :shade "Green")
                      (make-ntc--struct :code "#2B797A" :name "Atoll" :shade "Green")
                      (make-ntc--struct :code "#3D4B52" :name "Atomic" :shade "Blue")
                      (make-ntc--struct :code "#FF9966" :name "Atomic Tangerine" :shade "Orange")
                      (make-ntc--struct :code "#9E6759" :name "Au Chico" :shade "Brown")
                      (make-ntc--struct :code "#372528" :name "Aubergine" :shade "Brown")
                      (make-ntc--struct :code "#712F2C" :name "Auburn" :shade "Brown")
                      (make-ntc--struct :code "#EFF8AA" :name "Australian Mint" :shade "Green")
                      (make-ntc--struct :code "#95986B" :name "Avocado" :shade "Green")
                      (make-ntc--struct :code "#63775A" :name "Axolotl" :shade "Green")
                      (make-ntc--struct :code "#F9C0C4" :name "Azalea" :shade "Red")
                      (make-ntc--struct :code "#293432" :name "Aztec" :shade "Green")
                      (make-ntc--struct :code "#F0FFFF" :name "Azure" :shade "Blue")
                      (make-ntc--struct :code "#6FFFFF" :name "Baby Blue" :shade "Blue")
                      (make-ntc--struct :code "#25597F" :name "Bahama Blue" :shade "Blue")
                      (make-ntc--struct :code "#A9C01C" :name "Bahia" :shade "Green")
                      (make-ntc--struct :code "#5C3317" :name "Baker's Chocolate" :shade "Brown")
                      (make-ntc--struct :code "#849CA9" :name "Bali Hai" :shade "Blue")
                      (make-ntc--struct :code "#3C3D3E" :name "Baltic Sea" :shade "Grey")
                      (make-ntc--struct :code "#FBE7B2" :name "Banana Mania" :shade "Yellow")
                      (make-ntc--struct :code "#878466" :name "Bandicoot" :shade "Green")
                      (make-ntc--struct :code "#D2C61F" :name "Barberry" :shade "Green")
                      (make-ntc--struct :code "#B6935C" :name "Barley Corn" :shade "Yellow")
                      (make-ntc--struct :code "#F7E5B7" :name "Barley White" :shade "Yellow")
                      (make-ntc--struct :code "#452E39" :name "Barossa" :shade "Violet")
                      (make-ntc--struct :code "#2C2C32" :name "Bastille" :shade "Blue")
                      (make-ntc--struct :code "#51574F" :name "Battleship Grey" :shade "Grey")
                      (make-ntc--struct :code "#7BB18D" :name "Bay Leaf" :shade "Green")
                      (make-ntc--struct :code "#353E64" :name "Bay Of Many" :shade "Blue")
                      (make-ntc--struct :code "#8F7777" :name "Bazaar" :shade "Brown")
                      (make-ntc--struct :code "#EBB9B3" :name "Beauty Bush" :shade "Red")
                      (make-ntc--struct :code "#926F5B" :name "Beaver" :shade "Brown")
                      (make-ntc--struct :code "#E9D7AB" :name "Beeswax" :shade "Yellow")
                      (make-ntc--struct :code "#F5F5DC" :name "Beige" :shade "Brown")
                      (make-ntc--struct :code "#86D2C1" :name "Bermuda" :shade "Green")
                      (make-ntc--struct :code "#6F8C9F" :name "Bermuda Grey" :shade "Blue")
                      (make-ntc--struct :code "#BCBFA8" :name "Beryl Green" :shade "Green")
                      (make-ntc--struct :code "#F4EFE0" :name "Bianca" :shade "Yellow")
                      (make-ntc--struct :code "#334046" :name "Big Stone" :shade "Blue")
                      (make-ntc--struct :code "#3E8027" :name "Bilbao" :shade "Green")
                      (make-ntc--struct :code "#AE99D2" :name "Biloba Flower" :shade "Violet")
                      (make-ntc--struct :code "#3F3726" :name "Birch" :shade "Yellow")
                      (make-ntc--struct :code "#D0C117" :name "Bird Flower" :shade "Green")
                      (make-ntc--struct :code "#2F3C53" :name "Biscay" :shade "Blue")
                      (make-ntc--struct :code "#486C7A" :name "Bismark" :shade "Blue")
                      (make-ntc--struct :code "#B5AC94" :name "Bison Hide" :shade "Yellow")
                      (make-ntc--struct :code "#FFE4C4" :name "Bisque" :shade "Brown")
                      (make-ntc--struct :code "#3D2B1F" :name "Bistre" :shade "Brown")
                      (make-ntc--struct :code "#88896C" :name "Bitter" :shade "Green")
                      (make-ntc--struct :code "#D2DB32" :name "Bitter Lemon" :shade "Green")
                      (make-ntc--struct :code "#FE6F5E" :name "Bittersweet" :shade "Orange")
                      (make-ntc--struct :code "#E7D2C8" :name "Bizarre" :shade "Orange")
                      (make-ntc--struct :code "#000000" :name "Black" :shade "Black")
                      (make-ntc--struct :code "#232E26" :name "Black Bean" :shade "Green")
                      (make-ntc--struct :code "#2C3227" :name "Black Forest" :shade "Green")
                      (make-ntc--struct :code "#E0DED7" :name "Black Haze" :shade "Grey")
                      (make-ntc--struct :code "#332C22" :name "Black Magic" :shade "Brown")
                      (make-ntc--struct :code "#383740" :name "Black Marlin" :shade "Blue")
                      (make-ntc--struct :code "#1E272C" :name "Black Pearl" :shade "Blue")
                      (make-ntc--struct :code "#2C2D3C" :name "Black Rock" :shade "Blue")
                      (make-ntc--struct :code "#532934" :name "Black Rose" :shade "Red")
                      (make-ntc--struct :code "#24252B" :name "Black Russian" :shade "Grey")
                      (make-ntc--struct :code "#E5E6DF" :name "Black Squeeze" :shade "Grey")
                      (make-ntc--struct :code "#E5E4DB" :name "Black White" :shade "Grey")
                      (make-ntc--struct :code "#43182F" :name "Blackberry" :shade "Violet")
                      (make-ntc--struct :code "#2E183B" :name "Blackcurrant" :shade "Violet")
                      (make-ntc--struct :code "#D9D0C1" :name "Blanc" :shade "Yellow")
                      (make-ntc--struct :code "#FFEBCD" :name "Blanched Almond" :shade "Brown")
                      (make-ntc--struct :code "#EBE1CE" :name "Bleach White" :shade "Yellow")
                      (make-ntc--struct :code "#A3E3ED" :name "Blizzard Blue" :shade "Blue")
                      (make-ntc--struct :code "#DFB1B6" :name "Blossom" :shade "Red")
                      (make-ntc--struct :code "#0000FF" :name "Blue" :shade "Blue")
                      (make-ntc--struct :code "#62777E" :name "Blue Bayoux" :shade "Blue")
                      (make-ntc--struct :code "#9999CC" :name "Blue Bell" :shade "Blue")
                      (make-ntc--struct :code "#E3D6E9" :name "Blue Chalk" :shade "Violet")
                      (make-ntc--struct :code "#262B2F" :name "Blue Charcoal" :shade "Blue")
                      (make-ntc--struct :code "#408F90" :name "Blue Chill" :shade "Green")
                      (make-ntc--struct :code "#4B2D72" :name "Blue Diamond" :shade "Violet")
                      (make-ntc--struct :code "#35514F" :name "Blue Dianne" :shade "Green")
                      (make-ntc--struct :code "#4B3C8E" :name "Blue Gem" :shade "Violet")
                      (make-ntc--struct :code "#BDBACE" :name "Blue Haze" :shade "Violet")
                      (make-ntc--struct :code "#00626F" :name "Blue Lagoon" :shade "Green")
                      (make-ntc--struct :code "#6A5BB1" :name "Blue Marguerite" :shade "Violet")
                      (make-ntc--struct :code "#D8F0D2" :name "Blue Romance" :shade "Green")
                      (make-ntc--struct :code "#78857A" :name "Blue Smoke" :shade "Green")
                      (make-ntc--struct :code "#166461" :name "Blue Stone" :shade "Green")
                      (make-ntc--struct :code "#8A2BE2" :name "Blue Violet" :shade "Violet")
                      (make-ntc--struct :code "#1E3442" :name "Blue Whale" :shade "Blue")
                      (make-ntc--struct :code "#3C4354" :name "Blue Zodiac" :shade "Blue")
                      (make-ntc--struct :code "#305C71" :name "Blumine" :shade "Blue")
                      (make-ntc--struct :code "#B55067" :name "Blush" :shade "Red")
                      (make-ntc--struct :code "#2A2725" :name "Bokara Grey" :shade "Grey")
                      (make-ntc--struct :code "#79443B" :name "Bole" :shade "Brown")
                      (make-ntc--struct :code "#AEAEAD" :name "Bombay" :shade "Grey")
                      (make-ntc--struct :code "#DFD7D2" :name "Bon Jour" :shade "Grey")
                      (make-ntc--struct :code "#0095B6" :name "Bondi Blue" :shade "Blue")
                      (make-ntc--struct :code "#DBC2AB" :name "Bone" :shade "Orange")
                      (make-ntc--struct :code "#4C1C24" :name "Bordeaux" :shade "Red")
                      (make-ntc--struct :code "#4C3D4E" :name "Bossanova" :shade "Violet")
                      (make-ntc--struct :code "#438EAC" :name "Boston Blue" :shade "Blue")
                      (make-ntc--struct :code "#92ACB4" :name "Botticelli" :shade "Blue")
                      (make-ntc--struct :code "#254636" :name "Bottle Green" :shade "Green")
                      (make-ntc--struct :code "#7C817C" :name "Boulder" :shade "Grey")
                      (make-ntc--struct :code "#A78199" :name "Bouquet" :shade "Violet")
                      (make-ntc--struct :code "#AF6C3E" :name "Bourbon" :shade "Orange")
                      (make-ntc--struct :code "#5B3D27" :name "Bracken" :shade "Brown")
                      (make-ntc--struct :code "#DCB68A" :name "Brandy" :shade "Orange")
                      (make-ntc--struct :code "#C07C40" :name "Brandy Punch" :shade "Orange")
                      (make-ntc--struct :code "#B6857A" :name "Brandy Rose" :shade "Red")
                      (make-ntc--struct :code "#B5A642" :name "Brass" :shade "Yellow")
                      (make-ntc--struct :code "#517B78" :name "Breaker Bay" :shade "Green")
                      (make-ntc--struct :code "#C62D42" :name "Brick Red" :shade "Red")
                      (make-ntc--struct :code "#F8EBDD" :name "Bridal Heath" :shade "Orange")
                      (make-ntc--struct :code "#FAE6DF" :name "Bridesmaid" :shade "Orange")
                      (make-ntc--struct :code "#66FF00" :name "Bright Green" :shade "Green")
                      (make-ntc--struct :code "#57595D" :name "Bright Grey" :shade "Grey")
                      (make-ntc--struct :code "#922A31" :name "Bright Red" :shade "Red")
                      (make-ntc--struct :code "#ECBD2C" :name "Bright Sun" :shade "Yellow")
                      (make-ntc--struct :code "#08E8DE" :name "Bright Turquoise" :shade "Blue")
                      (make-ntc--struct :code "#FF55A3" :name "Brilliant Rose" :shade "Red")
                      (make-ntc--struct :code "#FB607F" :name "Brink Pink" :shade "Red")
                      (make-ntc--struct :code "#004225" :name "British Racing Green" :shade "Green")
                      (make-ntc--struct :code "#A79781" :name "Bronco" :shade "Brown")
                      (make-ntc--struct :code "#CD7F32" :name "Bronze" :shade "Brown")
                      (make-ntc--struct :code "#584C25" :name "Bronze Olive" :shade "Yellow")
                      (make-ntc--struct :code "#434C28" :name "Bronzetone" :shade "Yellow")
                      (make-ntc--struct :code "#EECC24" :name "Broom" :shade "Yellow")
                      (make-ntc--struct :code "#A52A2A" :name "Brown" :shade "Brown")
                      (make-ntc--struct :code "#53331E" :name "Brown Bramble" :shade "Brown")
                      (make-ntc--struct :code "#594537" :name "Brown Derby" :shade "Brown")
                      (make-ntc--struct :code "#3C241B" :name "Brown Pod" :shade "Brown")
                      (make-ntc--struct :code "#E6F2EA" :name "Bubbles" :shade "Green")
                      (make-ntc--struct :code "#6E5150" :name "Buccaneer" :shade "Red")
                      (make-ntc--struct :code "#A5A88F" :name "Bud" :shade "Green")
                      (make-ntc--struct :code "#BC9B1B" :name "Buddha Gold" :shade "Yellow")
                      (make-ntc--struct :code "#F0DC82" :name "Buff" :shade "Yellow")
                      (make-ntc--struct :code "#482427" :name "Bulgarian Rose" :shade "Red")
                      (make-ntc--struct :code "#75442B" :name "Bull Shot" :shade "Orange")
                      (make-ntc--struct :code "#292C2F" :name "Bunker" :shade "Grey")
                      (make-ntc--struct :code "#2B3449" :name "Bunting" :shade "Blue")
                      (make-ntc--struct :code "#800020" :name "Burgundy" :shade "Red")
                      (make-ntc--struct :code "#DEB887" :name "Burly Wood" :shade "Brown")
                      (make-ntc--struct :code "#234537" :name "Burnham" :shade "Green")
                      (make-ntc--struct :code "#D08363" :name "Burning Sand" :shade "Orange")
                      (make-ntc--struct :code "#582124" :name "Burnt Crimson" :shade "Red")
                      (make-ntc--struct :code "#FF7034" :name "Burnt Orange" :shade "Orange")
                      (make-ntc--struct :code "#E97451" :name "Burnt Sienna" :shade "Brown")
                      (make-ntc--struct :code "#8A3324" :name "Burnt Umber" :shade "Brown")
                      (make-ntc--struct :code "#DA9429" :name "Buttercup" :shade "Yellow")
                      (make-ntc--struct :code "#9D702E" :name "Buttered Rum" :shade "Yellow")
                      (make-ntc--struct :code "#68578C" :name "Butterfly Bush" :shade "Violet")
                      (make-ntc--struct :code "#F6E0A4" :name "Buttermilk" :shade "Yellow")
                      (make-ntc--struct :code "#F1EBDA" :name "Buttery White" :shade "Yellow")
                      (make-ntc--struct :code "#4A2E32" :name "Cab Sav" :shade "Red")
                      (make-ntc--struct :code "#CD526C" :name "Cabaret" :shade "Red")
                      (make-ntc--struct :code "#4C5544" :name "Cabbage Pont" :shade "Green")
                      (make-ntc--struct :code "#5B6F55" :name "Cactus" :shade "Green")
                      (make-ntc--struct :code "#5F9EA0" :name "Cadet Blue" :shade "Blue")
                      (make-ntc--struct :code "#984961" :name "Cadillac" :shade "Red")
                      (make-ntc--struct :code "#6A4928" :name "Cafe Royale" :shade "Brown")
                      (make-ntc--struct :code "#D5B185" :name "Calico" :shade "Brown")
                      (make-ntc--struct :code "#E98C3A" :name "California" :shade "Orange")
                      (make-ntc--struct :code "#3D7188" :name "Calypso" :shade "Blue")
                      (make-ntc--struct :code "#206937" :name "Camarone" :shade "Green")
                      (make-ntc--struct :code "#803A4B" :name "Camelot" :shade "Red")
                      (make-ntc--struct :code "#CCA483" :name "Cameo" :shade "Brown")
                      (make-ntc--struct :code "#4F4D32" :name "Camouflage" :shade "Yellow")
                      (make-ntc--struct :code "#78866B" :name "Camouflage Green" :shade "Green")
                      (make-ntc--struct :code "#D08A9B" :name "Can Can" :shade "Red")
                      (make-ntc--struct :code "#FFFF99" :name "Canary" :shade "Yellow")
                      (make-ntc--struct :code "#8E5164" :name "Cannon Pink" :shade "Red")
                      (make-ntc--struct :code "#4E5552" :name "Cape Cod" :shade "Grey")
                      (make-ntc--struct :code "#FEE0A5" :name "Cape Honey" :shade "Yellow")
                      (make-ntc--struct :code "#75482F" :name "Cape Palliser" :shade "Orange")
                      (make-ntc--struct :code "#AFC182" :name "Caper" :shade "Green")
                      (make-ntc--struct :code "#592720" :name "Caput Mortuum" :shade "Brown")
                      (make-ntc--struct :code "#FFD59A" :name "Caramel" :shade "Yellow")
                      (make-ntc--struct :code "#EBE5D5" :name "Cararra" :shade "Green")
                      (make-ntc--struct :code "#1B3427" :name "Cardin Green" :shade "Green")
                      (make-ntc--struct :code "#C41E3A" :name "Cardinal" :shade "Red")
                      (make-ntc--struct :code "#C99AA0" :name "Careys Pink" :shade "Red")
                      (make-ntc--struct :code "#00CC99" :name "Caribbean Green" :shade "Green")
                      (make-ntc--struct :code "#E68095" :name "Carissma" :shade "Red")
                      (make-ntc--struct :code "#F5F9CB" :name "Carla" :shade "Green")
                      (make-ntc--struct :code "#960018" :name "Carmine" :shade "Red")
                      (make-ntc--struct :code "#5B3A24" :name "Carnaby Tan" :shade "Brown")
                      (make-ntc--struct :code "#FFA6C9" :name "Carnation Pink" :shade "Red")
                      (make-ntc--struct :code "#F8DBE0" :name "Carousel Pink" :shade "Red")
                      (make-ntc--struct :code "#ED9121" :name "Carrot Orange" :shade "Orange")
                      (make-ntc--struct :code "#F0B253" :name "Casablanca" :shade "Yellow")
                      (make-ntc--struct :code "#3F545A" :name "Casal" :shade "Blue")
                      (make-ntc--struct :code "#8CA8A0" :name "Cascade" :shade "Green")
                      (make-ntc--struct :code "#D1B399" :name "Cashmere" :shade "Brown")
                      (make-ntc--struct :code "#AAB5B8" :name "Casper" :shade "Blue")
                      (make-ntc--struct :code "#44232F" :name "Castro" :shade "Red")
                      (make-ntc--struct :code "#273C5A" :name "Catalina Blue" :shade "Blue")
                      (make-ntc--struct :code "#E0E4DC" :name "Catskill White" :shade "Grey")
                      (make-ntc--struct :code "#E0B8B1" :name "Cavern Pink" :shade "Red")
                      (make-ntc--struct :code "#9271A7" :name "Ce Soir" :shade "Violet")
                      (make-ntc--struct :code "#463430" :name "Cedar" :shade "Brown")
                      (make-ntc--struct :code "#ACE1AF" :name "Celadon" :shade "Green")
                      (make-ntc--struct :code "#B4C04C" :name "Celery" :shade "Green")
                      (make-ntc--struct :code "#D2D2C0" :name "Celeste" :shade "Green")
                      (make-ntc--struct :code "#3A4E5F" :name "Cello" :shade "Blue")
                      (make-ntc--struct :code "#2B3F36" :name "Celtic" :shade "Green")
                      (make-ntc--struct :code "#857158" :name "Cement" :shade "Brown")
                      (make-ntc--struct :code "#DE3163" :name "Cerise" :shade "Violet")
                      (make-ntc--struct :code "#007BA7" :name "Cerulean" :shade "Blue")
                      (make-ntc--struct :code "#2A52BE" :name "Cerulean Blue" :shade "Blue")
                      (make-ntc--struct :code "#FDE9E0" :name "Chablis" :shade "Red")
                      (make-ntc--struct :code "#5A6E41" :name "Chalet Green" :shade "Green")
                      (make-ntc--struct :code "#DFC281" :name "Chalky" :shade "Yellow")
                      (make-ntc--struct :code "#475877" :name "Chambray" :shade "Blue")
                      (make-ntc--struct :code "#E8CD9A" :name "Chamois" :shade "Yellow")
                      (make-ntc--struct :code "#EED9B6" :name "Champagne" :shade "Yellow")
                      (make-ntc--struct :code "#EDB8C7" :name "Chantilly" :shade "Red")
                      (make-ntc--struct :code "#394043" :name "Charade" :shade "Blue")
                      (make-ntc--struct :code "#464646" :name "Charcoal" :shade "Grey")
                      (make-ntc--struct :code "#F8EADF" :name "Chardon" :shade "Orange")
                      (make-ntc--struct :code "#FFC878" :name "Chardonnay" :shade "Yellow")
                      (make-ntc--struct :code "#A4DCE6" :name "Charlotte" :shade "Blue")
                      (make-ntc--struct :code "#D0748B" :name "Charm" :shade "Red")
                      (make-ntc--struct :code "#7FFF00" :name "Chartreuse" :shade "Green")
                      (make-ntc--struct :code "#DFFF00" :name "Chartreuse Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#419F59" :name "Chateau Green" :shade "Green")
                      (make-ntc--struct :code "#B3ABB6" :name "Chatelle" :shade "Violet")
                      (make-ntc--struct :code "#2C5971" :name "Chathams Blue" :shade "Blue")
                      (make-ntc--struct :code "#88A95B" :name "Chelsea Cucumber" :shade "Green")
                      (make-ntc--struct :code "#95532F" :name "Chelsea Gem" :shade "Orange")
                      (make-ntc--struct :code "#DEC371" :name "Chenin" :shade "Yellow")
                      (make-ntc--struct :code "#F5CD82" :name "Cherokee" :shade "Yellow")
                      (make-ntc--struct :code "#372D52" :name "Cherry Pie" :shade "Violet")
                      (make-ntc--struct :code "#F5D7DC" :name "Cherub" :shade "Red")
                      (make-ntc--struct :code "#B94E48" :name "Chestnut" :shade "Brown")
                      (make-ntc--struct :code "#666FB4" :name "Chetwode Blue" :shade "Blue")
                      (make-ntc--struct :code "#5B5D56" :name "Chicago" :shade "Grey")
                      (make-ntc--struct :code "#F0F5BB" :name "Chiffon" :shade "Green")
                      (make-ntc--struct :code "#D05E34" :name "Chilean Fire" :shade "Orange")
                      (make-ntc--struct :code "#F9F7DE" :name "Chilean Heath" :shade "Green")
                      (make-ntc--struct :code "#FBF3D3" :name "China Ivory" :shade "Green")
                      (make-ntc--struct :code "#B8AD8A" :name "Chino" :shade "Yellow")
                      (make-ntc--struct :code "#9DD3A8" :name "Chinook" :shade "Green")
                      (make-ntc--struct :code "#D2691E" :name "Chocolate" :shade "Brown")
                      (make-ntc--struct :code "#382161" :name "Christalle" :shade "Violet")
                      (make-ntc--struct :code "#71A91D" :name "Christi" :shade "Green")
                      (make-ntc--struct :code "#BF652E" :name "Christine" :shade "Orange")
                      (make-ntc--struct :code "#CAC7B7" :name "Chrome White" :shade "Green")
                      (make-ntc--struct :code "#7D4E38" :name "Cigar" :shade "Brown")
                      (make-ntc--struct :code "#242A2E" :name "Cinder" :shade "Grey")
                      (make-ntc--struct :code "#FBD7CC" :name "Cinderella" :shade "Red")
                      (make-ntc--struct :code "#E34234" :name "Cinnabar" :shade "Red")
                      (make-ntc--struct :code "#5D3B2E" :name "Cioccolato" :shade "Brown")
                      (make-ntc--struct :code "#8E9A21" :name "Citron" :shade "Green")
                      (make-ntc--struct :code "#9FB70A" :name "Citrus" :shade "Green")
                      (make-ntc--struct :code "#D2B3A9" :name "Clam Shell" :shade "Orange")
                      (make-ntc--struct :code "#6E2233" :name "Claret" :shade "Red")
                      (make-ntc--struct :code "#F4C8DB" :name "Classic Rose" :shade "Violet")
                      (make-ntc--struct :code "#897E59" :name "Clay Creek" :shade "Yellow")
                      (make-ntc--struct :code "#DFEFEA" :name "Clear Day" :shade "Green")
                      (make-ntc--struct :code "#463623" :name "Clinker" :shade "Brown")
                      (make-ntc--struct :code "#C2BCB1" :name "Cloud" :shade "Yellow")
                      (make-ntc--struct :code "#353E4F" :name "Cloud Burst" :shade "Blue")
                      (make-ntc--struct :code "#B0A99F" :name "Cloudy" :shade "Brown")
                      (make-ntc--struct :code "#47562F" :name "Clover" :shade "Green")
                      (make-ntc--struct :code "#0047AB" :name "Cobalt" :shade "Blue")
                      (make-ntc--struct :code "#4F3835" :name "Cocoa Bean" :shade "Red")
                      (make-ntc--struct :code "#35281E" :name "Cocoa Brown" :shade "Brown")
                      (make-ntc--struct :code "#E1DABB" :name "Coconut Cream" :shade "Green")
                      (make-ntc--struct :code "#2D3032" :name "Cod Grey" :shade "Grey")
                      (make-ntc--struct :code "#726751" :name "Coffee" :shade "Yellow")
                      (make-ntc--struct :code "#362D26" :name "Coffee Bean" :shade "Brown")
                      (make-ntc--struct :code "#9A463D" :name "Cognac" :shade "Red")
                      (make-ntc--struct :code "#3C2F23" :name "Cola" :shade "Brown")
                      (make-ntc--struct :code "#9D8ABF" :name "Cold Purple" :shade "Violet")
                      (make-ntc--struct :code "#CAB5B2" :name "Cold Turkey" :shade "Red")
                      (make-ntc--struct :code "#9BDDFF" :name "Columbia Blue" :shade "Blue")
                      (make-ntc--struct :code "#636373" :name "Comet" :shade "Blue")
                      (make-ntc--struct :code "#4C785C" :name "Como" :shade "Green")
                      (make-ntc--struct :code "#A0B1AE" :name "Conch" :shade "Green")
                      (make-ntc--struct :code "#827F79" :name "Concord" :shade "Grey")
                      (make-ntc--struct :code "#D2D1CD" :name "Concrete" :shade "Grey")
                      (make-ntc--struct :code "#DDCB46" :name "Confetti" :shade "Green")
                      (make-ntc--struct :code "#654D49" :name "Congo Brown" :shade "Brown")
                      (make-ntc--struct :code "#B1DD52" :name "Conifer" :shade "Green")
                      (make-ntc--struct :code "#C16F68" :name "Contessa" :shade "Red")
                      (make-ntc--struct :code "#DA8A67" :name "Copper" :shade "Red")
                      (make-ntc--struct :code "#77422C" :name "Copper Canyon" :shade "Orange")
                      (make-ntc--struct :code "#996666" :name "Copper Rose" :shade "Violet")
                      (make-ntc--struct :code "#95524C" :name "Copper Rust" :shade "Red")
                      (make-ntc--struct :code "#FF7F50" :name "Coral" :shade "Orange")
                      (make-ntc--struct :code "#F5D0C9" :name "Coral Candy" :shade "Red")
                      (make-ntc--struct :code "#FF4040" :name "Coral Red" :shade "Red")
                      (make-ntc--struct :code "#AB6E67" :name "Coral Tree" :shade "Red")
                      (make-ntc--struct :code "#404D49" :name "Corduroy" :shade "Green")
                      (make-ntc--struct :code "#BBB58D" :name "Coriander" :shade "Green")
                      (make-ntc--struct :code "#5A4C42" :name "Cork" :shade "Brown")
                      (make-ntc--struct :code "#FBEC5D" :name "Corn" :shade "Yellow")
                      (make-ntc--struct :code "#F8F3C4" :name "Corn Field" :shade "Green")
                      (make-ntc--struct :code "#42426F" :name "Corn Flower Blue" :shade "Blue")
                      (make-ntc--struct :code "#8D702A" :name "Corn Harvest" :shade "Yellow")
                      (make-ntc--struct :code "#FFF8DC" :name "Corn Silk" :shade "Yellow")
                      (make-ntc--struct :code "#93CCEA" :name "Cornflower" :shade "Blue")
                      (make-ntc--struct :code "#6495ED" :name "Cornflower Blue" :shade "Blue")
                      (make-ntc--struct :code "#E9BA81" :name "Corvette" :shade "Orange")
                      (make-ntc--struct :code "#794D60" :name "Cosmic" :shade "Violet")
                      (make-ntc--struct :code "#E1F8E7" :name "Cosmic Latte" :shade "White")
                      (make-ntc--struct :code "#FCD5CF" :name "Cosmos" :shade "Red")
                      (make-ntc--struct :code "#625D2A" :name "Costa Del Sol" :shade "Green")
                      (make-ntc--struct :code "#FFB7D5" :name "Cotton Candy" :shade "Red")
                      (make-ntc--struct :code "#BFBAAF" :name "Cotton Seed" :shade "Yellow")
                      (make-ntc--struct :code "#1B4B35" :name "County Green" :shade "Green")
                      (make-ntc--struct :code "#443736" :name "Cowboy" :shade "Brown")
                      (make-ntc--struct :code "#87382F" :name "Crab Apple" :shade "Red")
                      (make-ntc--struct :code "#A65648" :name "Crail" :shade "Red")
                      (make-ntc--struct :code "#DB5079" :name "Cranberry" :shade "Red")
                      (make-ntc--struct :code "#4D3E3C" :name "Crater Brown" :shade "Brown")
                      (make-ntc--struct :code "#FFFDD0" :name "Cream" :shade "White")
                      (make-ntc--struct :code "#FFE39B" :name "Cream Brulee" :shade "Yellow")
                      (make-ntc--struct :code "#EEC051" :name "Cream Can" :shade "Yellow")
                      (make-ntc--struct :code "#393227" :name "Creole" :shade "Brown")
                      (make-ntc--struct :code "#77712B" :name "Crete" :shade "Green")
                      (make-ntc--struct :code "#DC143C" :name "Crimson" :shade "Red")
                      (make-ntc--struct :code "#706950" :name "Crocodile" :shade "Yellow")
                      (make-ntc--struct :code "#763C33" :name "Crown Of Thorns" :shade "Red")
                      (make-ntc--struct :code "#B4E2D5" :name "Cruise" :shade "Green")
                      (make-ntc--struct :code "#165B31" :name "Crusoe" :shade "Green")
                      (make-ntc--struct :code "#F38653" :name "Crusta" :shade "Orange")
                      (make-ntc--struct :code "#784430" :name "Cumin" :shade "Orange")
                      (make-ntc--struct :code "#F5F4C1" :name "Cumulus" :shade "Green")
                      (make-ntc--struct :code "#F5B2C5" :name "Cupid" :shade "Red")
                      (make-ntc--struct :code "#3D85B8" :name "Curious Blue" :shade "Blue")
                      (make-ntc--struct :code "#5C8173" :name "Cutty Sark" :shade "Green")
                      (make-ntc--struct :code "#0F4645" :name "Cyprus" :shade "Green")
                      (make-ntc--struct :code "#EDD2A4" :name "Dairy Cream" :shade "Yellow")
                      (make-ntc--struct :code "#5B3E90" :name "Daisy Bush" :shade "Violet")
                      (make-ntc--struct :code "#664A2D" :name "Dallas" :shade "Brown")
                      (make-ntc--struct :code "#FED85D" :name "Dandelion" :shade "Yellow")
                      (make-ntc--struct :code "#5B89C0" :name "Danube" :shade "Blue")
                      (make-ntc--struct :code "#00008B" :name "Dark Blue" :shade "Blue")
                      (make-ntc--struct :code "#654321" :name "Dark Brown" :shade "Brown")
                      (make-ntc--struct :code "#08457E" :name "Dark Cerulean" :shade "Blue")
                      (make-ntc--struct :code "#986960" :name "Dark Chestnut" :shade "Red")
                      (make-ntc--struct :code "#CD5B45" :name "Dark Coral" :shade "Orange")
                      (make-ntc--struct :code "#008B8B" :name "Dark Cyan" :shade "Green")
                      (make-ntc--struct :code "#B8860B" :name "Dark Goldenrod" :shade "Yellow")
                      (make-ntc--struct :code "#A9A9A9" :name "Dark Gray" :shade "Grey")
                      (make-ntc--struct :code "#013220" :name "Dark Green" :shade "Green")
                      (make-ntc--struct :code "#4A766E" :name "Dark Green Copper" :shade "Green")
                      (make-ntc--struct :code "#BDB76B" :name "Dark Khaki" :shade "Yellow")
                      (make-ntc--struct :code "#8B008B" :name "Dark Magenta" :shade "Violet")
                      (make-ntc--struct :code "#556B2F" :name "Dark Olive Green" :shade "Green")
                      (make-ntc--struct :code "#FF8C00" :name "Dark Orange" :shade "Orange")
                      (make-ntc--struct :code "#9932CC" :name "Dark Orchid" :shade "Violet")
                      (make-ntc--struct :code "#03C03C" :name "Dark Pastel Green" :shade "Green")
                      (make-ntc--struct :code "#E75480" :name "Dark Pink" :shade "Red")
                      (make-ntc--struct :code "#871F78" :name "Dark Purple" :shade "Violet")
                      (make-ntc--struct :code "#8B0000" :name "Dark Red" :shade "Red")
                      (make-ntc--struct :code "#45362B" :name "Dark Rum" :shade "Brown")
                      (make-ntc--struct :code "#E9967A" :name "Dark Salmon" :shade "Orange")
                      (make-ntc--struct :code "#8FBC8F" :name "Dark Sea Green" :shade "Green")
                      (make-ntc--struct :code "#465352" :name "Dark Slate" :shade "Green")
                      (make-ntc--struct :code "#483D8B" :name "Dark Slate Blue" :shade "Blue")
                      (make-ntc--struct :code "#2F4F4F" :name "Dark Slate Grey" :shade "Grey")
                      (make-ntc--struct :code "#177245" :name "Dark Spring Green" :shade "Green")
                      (make-ntc--struct :code "#97694F" :name "Dark Tan" :shade "Brown")
                      (make-ntc--struct :code "#FFA812" :name "Dark Tangerine" :shade "Orange")
                      (make-ntc--struct :code "#00CED1" :name "Dark Turquoise" :shade "Blue")
                      (make-ntc--struct :code "#9400D3" :name "Dark Violet" :shade "Violet")
                      (make-ntc--struct :code "#855E42" :name "Dark Wood" :shade "Brown")
                      (make-ntc--struct :code "#788878" :name "Davy's Grey" :shade "Grey")
                      (make-ntc--struct :code "#9F9D91" :name "Dawn" :shade "Green")
                      (make-ntc--struct :code "#E6D6CD" :name "Dawn Pink" :shade "Orange")
                      (make-ntc--struct :code "#85CA87" :name "De York" :shade "Green")
                      (make-ntc--struct :code "#CCCF82" :name "Deco" :shade "Green")
                      (make-ntc--struct :code "#E36F8A" :name "Deep Blush" :shade "Red")
                      (make-ntc--struct :code "#51412D" :name "Deep Bronze" :shade "Brown")
                      (make-ntc--struct :code "#DA3287" :name "Deep Cerise" :shade "Violet")
                      (make-ntc--struct :code "#193925" :name "Deep Fir" :shade "Green")
                      (make-ntc--struct :code "#343467" :name "Deep Koamaru" :shade "Violet")
                      (make-ntc--struct :code "#9955BB" :name "Deep Lilac" :shade "Violet")
                      (make-ntc--struct :code "#CC00CC" :name "Deep Magenta" :shade "Violet")
                      (make-ntc--struct :code "#FF1493" :name "Deep Pink" :shade "Red")
                      (make-ntc--struct :code "#167E65" :name "Deep Sea" :shade "Green")
                      (make-ntc--struct :code "#00BFFF" :name "Deep Sky Blue" :shade "Blue")
                      (make-ntc--struct :code "#19443C" :name "Deep Teal" :shade "Green")
                      (make-ntc--struct :code "#B5998E" :name "Del Rio" :shade "Brown")
                      (make-ntc--struct :code "#486531" :name "Dell" :shade "Green")
                      (make-ntc--struct :code "#999B95" :name "Delta" :shade "Grey")
                      (make-ntc--struct :code "#8272A4" :name "Deluge" :shade "Violet")
                      (make-ntc--struct :code "#1560BD" :name "Denim" :shade "Blue")
                      (make-ntc--struct :code "#F9E4C6" :name "Derby" :shade "Yellow")
                      (make-ntc--struct :code "#A15F3B" :name "Desert" :shade "Orange")
                      (make-ntc--struct :code "#EDC9AF" :name "Desert Sand" :shade "Brown")
                      (make-ntc--struct :code "#EDE7E0" :name "Desert Storm" :shade "Grey")
                      (make-ntc--struct :code "#E7F2E9" :name "Dew" :shade "Green")
                      (make-ntc--struct :code "#322C2B" :name "Diesel" :shade "Grey")
                      (make-ntc--struct :code "#696969" :name "Dim Gray" :shade "Grey")
                      (make-ntc--struct :code "#607C47" :name "Dingley" :shade "Green")
                      (make-ntc--struct :code "#892D4F" :name "Disco" :shade "Red")
                      (make-ntc--struct :code "#CD8431" :name "Dixie" :shade "Yellow")
                      (make-ntc--struct :code "#1E90FF" :name "Dodger Blue" :shade "Blue")
                      (make-ntc--struct :code "#F5F171" :name "Dolly" :shade "Green")
                      (make-ntc--struct :code "#6A6873" :name "Dolphin" :shade "Violet")
                      (make-ntc--struct :code "#6C5B4C" :name "Domino" :shade "Brown")
                      (make-ntc--struct :code "#5A4F51" :name "Don Juan" :shade "Brown")
                      (make-ntc--struct :code "#816E5C" :name "Donkey Brown" :shade "Brown")
                      (make-ntc--struct :code "#6E5F56" :name "Dorado" :shade "Brown")
                      (make-ntc--struct :code "#E4CF99" :name "Double Colonial White" :shade "Yellow")
                      (make-ntc--struct :code "#E9DCBE" :name "Double Pearl Lusta" :shade "Yellow")
                      (make-ntc--struct :code "#D2C3A3" :name "Double Spanish White" :shade "Yellow")
                      (make-ntc--struct :code "#777672" :name "Dove Grey" :shade "Grey")
                      (make-ntc--struct :code "#6FD2BE" :name "Downy" :shade "Green")
                      (make-ntc--struct :code "#FBEB9B" :name "Drover" :shade "Yellow")
                      (make-ntc--struct :code "#514F4A" :name "Dune" :shade "Grey")
                      (make-ntc--struct :code "#E5CAC0" :name "Dust Storm" :shade "Orange")
                      (make-ntc--struct :code "#AC9B9B" :name "Dusty Grey" :shade "Grey")
                      (make-ntc--struct :code "#F0DFBB" :name "Dutch White" :shade "Yellow")
                      (make-ntc--struct :code "#B0AC94" :name "Eagle" :shade "Green")
                      (make-ntc--struct :code "#B8A722" :name "Earls Green" :shade "Green")
                      (make-ntc--struct :code "#FBF2DB" :name "Early Dawn" :shade "Yellow")
                      (make-ntc--struct :code "#47526E" :name "East Bay" :shade "Blue")
                      (make-ntc--struct :code "#AA8CBC" :name "East Side" :shade "Violet")
                      (make-ntc--struct :code "#00879F" :name "Eastern Blue" :shade "Blue")
                      (make-ntc--struct :code "#E6D8D4" :name "Ebb" :shade "Red")
                      (make-ntc--struct :code "#313337" :name "Ebony" :shade "Grey")
                      (make-ntc--struct :code "#323438" :name "Ebony Clay" :shade "Grey")
                      (make-ntc--struct :code "#A4AFCD" :name "Echo Blue" :shade "Blue")
                      (make-ntc--struct :code "#3F3939" :name "Eclipse" :shade "Grey")
                      (make-ntc--struct :code "#C2B280" :name "Ecru" :shade "Brown")
                      (make-ntc--struct :code "#D6D1C0" :name "Ecru White" :shade "Green")
                      (make-ntc--struct :code "#C96138" :name "Ecstasy" :shade "Orange")
                      (make-ntc--struct :code "#266255" :name "Eden" :shade "Green")
                      (make-ntc--struct :code "#C1D8C5" :name "Edgewater" :shade "Green")
                      (make-ntc--struct :code "#97A49A" :name "Edward" :shade "Green")
                      (make-ntc--struct :code "#F9E4C5" :name "Egg Sour" :shade "Yellow")
                      (make-ntc--struct :code "#990066" :name "Eggplant" :shade "Violet")
                      (make-ntc--struct :code "#1034A6" :name "Egyptian Blue" :shade "Blue")
                      (make-ntc--struct :code "#39392C" :name "El Paso" :shade "Green")
                      (make-ntc--struct :code "#8F4E45" :name "El Salva" :shade "Red")
                      (make-ntc--struct :code "#7DF9FF" :name "Electric Blue" :shade "Blue")
                      (make-ntc--struct :code "#6600FF" :name "Electric Indigo" :shade "Violet")
                      (make-ntc--struct :code "#CCFF00" :name "Electric Lime" :shade "Green")
                      (make-ntc--struct :code "#BF00FF" :name "Electric Purple" :shade "Violet")
                      (make-ntc--struct :code "#243640" :name "Elephant" :shade "Blue")
                      (make-ntc--struct :code "#1B8A6B" :name "Elf Green" :shade "Green")
                      (make-ntc--struct :code "#297B76" :name "Elm" :shade "Green")
                      (make-ntc--struct :code "#50C878" :name "Emerald" :shade "Green")
                      (make-ntc--struct :code "#6E3974" :name "Eminence" :shade "Violet")
                      (make-ntc--struct :code "#50494A" :name "Emperor" :shade "Grey")
                      (make-ntc--struct :code "#7C7173" :name "Empress" :shade "Grey")
                      (make-ntc--struct :code "#29598B" :name "Endeavour" :shade "Blue")
                      (make-ntc--struct :code "#F5D752" :name "Energy Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#274234" :name "English Holly" :shade "Green")
                      (make-ntc--struct :code "#8BA58F" :name "Envy" :shade "Green")
                      (make-ntc--struct :code "#DAB160" :name "Equator" :shade "Yellow")
                      (make-ntc--struct :code "#4E312D" :name "Espresso" :shade "Red")
                      (make-ntc--struct :code "#2D2F28" :name "Eternity" :shade "Green")
                      (make-ntc--struct :code "#329760" :name "Eucalyptus" :shade "Green")
                      (make-ntc--struct :code "#CDA59C" :name "Eunry" :shade "Red")
                      (make-ntc--struct :code "#26604F" :name "Evening Sea" :shade "Green")
                      (make-ntc--struct :code "#264334" :name "Everglade" :shade "Green")
                      (make-ntc--struct :code "#F3E5DC" :name "Fair Pink" :shade "Orange")
                      (make-ntc--struct :code "#6E5A5B" :name "Falcon" :shade "Brown")
                      (make-ntc--struct :code "#C19A6B" :name "Fallow" :shade "Brown")
                      (make-ntc--struct :code "#801818" :name "Falu Red" :shade "Red")
                      (make-ntc--struct :code "#F2E6DD" :name "Fantasy" :shade "Orange")
                      (make-ntc--struct :code "#625665" :name "Fedora" :shade "Violet")
                      (make-ntc--struct :code "#A5D785" :name "Feijoa" :shade "Green")
                      (make-ntc--struct :code "#4D5D53" :name "Feldgrau" :shade "Grey")
                      (make-ntc--struct :code "#D19275" :name "Feldspar" :shade "Red")
                      (make-ntc--struct :code "#63B76C" :name "Fern" :shade "Green")
                      (make-ntc--struct :code "#4F7942" :name "Fern Green" :shade "Green")
                      (make-ntc--struct :code "#876A68" :name "Ferra" :shade "Brown")
                      (make-ntc--struct :code "#EACC4A" :name "Festival" :shade "Yellow")
                      (make-ntc--struct :code "#DBE0D0" :name "Feta" :shade "Green")
                      (make-ntc--struct :code "#B1592F" :name "Fiery Orange" :shade "Orange")
                      (make-ntc--struct :code "#636F22" :name "Fiji Green" :shade "Green")
                      (make-ntc--struct :code "#75785A" :name "Finch" :shade "Green")
                      (make-ntc--struct :code "#61755B" :name "Finlandia" :shade "Green")
                      (make-ntc--struct :code "#694554" :name "Finn" :shade "Violet")
                      (make-ntc--struct :code "#4B5A62" :name "Fiord" :shade "Blue")
                      (make-ntc--struct :code "#8F3F2A" :name "Fire" :shade "Orange")
                      (make-ntc--struct :code "#B22222" :name "Fire Brick" :shade "Red")
                      (make-ntc--struct :code "#E09842" :name "Fire Bush" :shade "Yellow")
                      (make-ntc--struct :code "#CE1620" :name "Fire Engine Red" :shade "Red")
                      (make-ntc--struct :code "#314643" :name "Firefly" :shade "Green")
                      (make-ntc--struct :code "#BE5C48" :name "Flame Pea" :shade "Orange")
                      (make-ntc--struct :code "#86282E" :name "Flame Red" :shade "Red")
                      (make-ntc--struct :code "#EA8645" :name "Flamenco" :shade "Orange")
                      (make-ntc--struct :code "#E1634F" :name "Flamingo" :shade "Orange")
                      (make-ntc--struct :code "#EEDC82" :name "Flax" :shade "Yellow")
                      (make-ntc--struct :code "#716E61" :name "Flint" :shade "Green")
                      (make-ntc--struct :code "#7A2E4D" :name "Flirt" :shade "Red")
                      (make-ntc--struct :code "#FFFAF0" :name "Floral White" :shade "White")
                      (make-ntc--struct :code "#D0EAE8" :name "Foam" :shade "Green")
                      (make-ntc--struct :code "#D5C7E8" :name "Fog" :shade "Violet")
                      (make-ntc--struct :code "#A7A69D" :name "Foggy Grey" :shade "Grey")
                      (make-ntc--struct :code "#228B22" :name "Forest Green" :shade "Green")
                      (make-ntc--struct :code "#FDEFDB" :name "Forget Me Not" :shade "Yellow")
                      (make-ntc--struct :code "#65ADB2" :name "Fountain Blue" :shade "Blue")
                      (make-ntc--struct :code "#FFD7A0" :name "Frangipani" :shade "Yellow")
                      (make-ntc--struct :code "#029D74" :name "Free Speech Aquamarine" :shade "Green")
                      (make-ntc--struct :code "#4156C5" :name "Free Speech Blue" :shade "Blue")
                      (make-ntc--struct :code "#09F911" :name "Free Speech Green" :shade "Green")
                      (make-ntc--struct :code "#E35BD8" :name "Free Speech Magenta" :shade "Red")
                      (make-ntc--struct :code "#C00000" :name "Free Speech Red" :shade "Red")
                      (make-ntc--struct :code "#BFBDC1" :name "French Grey" :shade "Grey")
                      (make-ntc--struct :code "#DEB7D9" :name "French Lilac" :shade "Violet")
                      (make-ntc--struct :code "#A4D2E0" :name "French Pass" :shade "Blue")
                      (make-ntc--struct :code "#F64A8A" :name "French Rose" :shade "Red")
                      (make-ntc--struct :code "#86837A" :name "Friar Grey" :shade "Grey")
                      (make-ntc--struct :code "#B4E1BB" :name "Fringy Flower" :shade "Green")
                      (make-ntc--struct :code "#E56D75" :name "Froly" :shade "Red")
                      (make-ntc--struct :code "#E1E4C5" :name "Frost" :shade "Green")
                      (make-ntc--struct :code "#E2F2E4" :name "Frosted Mint" :shade "Green")
                      (make-ntc--struct :code "#DBE5D2" :name "Frostee" :shade "Green")
                      (make-ntc--struct :code "#4BA351" :name "Fruit Salad" :shade "Green")
                      (make-ntc--struct :code "#C154C1" :name "Fuchsia" :shade "Violet")
                      (make-ntc--struct :code "#FF77FF" :name "Fuchsia Pink" :shade "Red")
                      (make-ntc--struct :code "#C2D62E" :name "Fuego" :shade "Green")
                      (make-ntc--struct :code "#D19033" :name "Fuel Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#335083" :name "Fun Blue" :shade "Blue")
                      (make-ntc--struct :code "#15633D" :name "Fun Green" :shade "Green")
                      (make-ntc--struct :code "#3C3B3C" :name "Fuscous Grey" :shade "Grey")
                      (make-ntc--struct :code "#C45655" :name "Fuzzy Wuzzy Brown" :shade "Brown")
                      (make-ntc--struct :code "#2C4641" :name "Gable Green" :shade "Green")
                      (make-ntc--struct :code "#DCDCDC" :name "Gainsboro" :shade "White")
                      (make-ntc--struct :code "#DCD7D1" :name "Gallery" :shade "Grey")
                      (make-ntc--struct :code "#D8A723" :name "Galliano" :shade "Yellow")
                      (make-ntc--struct :code "#E49B0F" :name "Gamboge" :shade "Yellow")
                      (make-ntc--struct :code "#C5832E" :name "Geebung" :shade "Yellow")
                      (make-ntc--struct :code "#31796D" :name "Genoa" :shade "Green")
                      (make-ntc--struct :code "#E77B75" :name "Geraldine" :shade "Red")
                      (make-ntc--struct :code "#CBD0CF" :name "Geyser" :shade "Grey")
                      (make-ntc--struct :code "#C0BFC7" :name "Ghost" :shade "Blue")
                      (make-ntc--struct :code "#F8F8FF" :name "Ghost White" :shade "White")
                      (make-ntc--struct :code "#564786" :name "Gigas" :shade "Violet")
                      (make-ntc--struct :code "#B9AD61" :name "Gimblet" :shade "Green")
                      (make-ntc--struct :code "#D9DFCD" :name "Gin" :shade "Green")
                      (make-ntc--struct :code "#F8EACA" :name "Gin Fizz" :shade "Yellow")
                      (make-ntc--struct :code "#EBD4AE" :name "Givry" :shade "Yellow")
                      (make-ntc--struct :code "#78B1BF" :name "Glacier" :shade "Blue")
                      (make-ntc--struct :code "#5F8151" :name "Glade Green" :shade "Green")
                      (make-ntc--struct :code "#786E4C" :name "Go Ben" :shade "Yellow")
                      (make-ntc--struct :code "#34533D" :name "Goblin" :shade "Green")
                      (make-ntc--struct :code "#FFD700" :name "Gold" :shade "Yellow")
                      (make-ntc--struct :code "#D56C30" :name "Gold Drop" :shade "Orange")
                      (make-ntc--struct :code "#E2B227" :name "Gold Tips" :shade "Yellow")
                      (make-ntc--struct :code "#CA8136" :name "Golden Bell" :shade "Orange")
                      (make-ntc--struct :code "#996515" :name "Golden Brown" :shade "Brown")
                      (make-ntc--struct :code "#F1CC2B" :name "Golden Dream" :shade "Yellow")
                      (make-ntc--struct :code "#EBDE31" :name "Golden Fizz" :shade "Green")
                      (make-ntc--struct :code "#F9D77E" :name "Golden Glow" :shade "Yellow")
                      (make-ntc--struct :code "#FCC200" :name "Golden Poppy" :shade "Yellow")
                      (make-ntc--struct :code "#EACE6A" :name "Golden Sand" :shade "Yellow")
                      (make-ntc--struct :code "#FFC152" :name "Golden Tainoi" :shade "Yellow")
                      (make-ntc--struct :code "#FFDF00" :name "Golden Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#DBDB70" :name "Goldenrod" :shade "Yellow")
                      (make-ntc--struct :code "#373332" :name "Gondola" :shade "Grey")
                      (make-ntc--struct :code "#29332B" :name "Gordons Green" :shade "Green")
                      (make-ntc--struct :code "#FDE336" :name "Gorse" :shade "Green")
                      (make-ntc--struct :code "#399F86" :name "Gossamer" :shade "Green")
                      (make-ntc--struct :code "#9FD385" :name "Gossip" :shade "Green")
                      (make-ntc--struct :code "#698890" :name "Gothic" :shade "Blue")
                      (make-ntc--struct :code "#51559B" :name "Governor Bay" :shade "Blue")
                      (make-ntc--struct :code "#CAB8A2" :name "Grain Brown" :shade "Yellow")
                      (make-ntc--struct :code "#FFCD73" :name "Grandis" :shade "Yellow")
                      (make-ntc--struct :code "#8B8265" :name "Granite Green" :shade "Yellow")
                      (make-ntc--struct :code "#C5E7CD" :name "Granny Apple" :shade "Green")
                      (make-ntc--struct :code "#7B948C" :name "Granny Smith" :shade "Green")
                      (make-ntc--struct :code "#9DE093" :name "Granny Smith Apple" :shade "Green")
                      (make-ntc--struct :code "#413D4B" :name "Grape" :shade "Violet")
                      (make-ntc--struct :code "#383428" :name "Graphite" :shade "Yellow")
                      (make-ntc--struct :code "#4A4B46" :name "Gravel" :shade "Grey")
                      (make-ntc--struct :code "#008000" :name "Green" :shade "Green")
                      (make-ntc--struct :code "#3E6334" :name "Green House" :shade "Green")
                      (make-ntc--struct :code "#393D2A" :name "Green Kelp" :shade "Green")
                      (make-ntc--struct :code "#526B2D" :name "Green Leaf" :shade "Green")
                      (make-ntc--struct :code "#BFC298" :name "Green Mist" :shade "Green")
                      (make-ntc--struct :code "#266242" :name "Green Pea" :shade "Green")
                      (make-ntc--struct :code "#9CA664" :name "Green Smoke" :shade "Green")
                      (make-ntc--struct :code "#A9AF99" :name "Green Spring" :shade "Green")
                      (make-ntc--struct :code "#23414E" :name "Green Vogue" :shade "Blue")
                      (make-ntc--struct :code "#2C2D24" :name "Green Waterloo" :shade "Green")
                      (make-ntc--struct :code "#DEDDCB" :name "Green White" :shade "Green")
                      (make-ntc--struct :code "#ADFF2F" :name "Green Yellow" :shade "Green")
                      (make-ntc--struct :code "#C14D36" :name "Grenadier" :shade "Orange")
                      (make-ntc--struct :code "#808080" :name "Grey" :shade "Grey")
                      (make-ntc--struct :code "#9FA3A7" :name "Grey Chateau" :shade "Grey")
                      (make-ntc--struct :code "#BDBAAE" :name "Grey Nickel" :shade "Green")
                      (make-ntc--struct :code "#D1D3CC" :name "Grey Nurse" :shade "Grey")
                      (make-ntc--struct :code "#A19A7F" :name "Grey Olive" :shade "Yellow")
                      (make-ntc--struct :code "#9391A0" :name "Grey Suit" :shade "Blue")
                      (make-ntc--struct :code "#465945" :name "Grey-Asparagus" :shade "Green")
                      (make-ntc--struct :code "#952E31" :name "Guardsman Red" :shade "Red")
                      (make-ntc--struct :code "#343F5C" :name "Gulf Blue" :shade "Blue")
                      (make-ntc--struct :code "#74B2A8" :name "Gulf Stream" :shade "Green")
                      (make-ntc--struct :code "#A4ADB0" :name "Gull Grey" :shade "Grey")
                      (make-ntc--struct :code "#ACC9B2" :name "Gum Leaf" :shade "Green")
                      (make-ntc--struct :code "#718F8A" :name "Gumbo" :shade "Green")
                      (make-ntc--struct :code "#484753" :name "Gun Powder" :shade "Violet")
                      (make-ntc--struct :code "#2C3539" :name "Gunmetal" :shade "Blue")
                      (make-ntc--struct :code "#7A7C76" :name "Gunsmoke" :shade "Grey")
                      (make-ntc--struct :code "#989171" :name "Gurkha" :shade "Green")
                      (make-ntc--struct :code "#9E8022" :name "Hacienda" :shade "Yellow")
                      (make-ntc--struct :code "#633528" :name "Hairy Heath" :shade "Brown")
                      (make-ntc--struct :code "#2C2A35" :name "Haiti" :shade "Violet")
                      (make-ntc--struct :code "#EDE7C8" :name "Half And Half" :shade "Green")
                      (make-ntc--struct :code "#558F93" :name "Half Baked" :shade "Blue")
                      (make-ntc--struct :code "#F2E5BF" :name "Half Colonial White" :shade "Yellow")
                      (make-ntc--struct :code "#FBF0D6" :name "Half Dutch White" :shade "Yellow")
                      (make-ntc--struct :code "#F1EAD7" :name "Half Pearl Lusta" :shade "Yellow")
                      (make-ntc--struct :code "#E6DBC7" :name "Half Spanish White" :shade "Yellow")
                      (make-ntc--struct :code "#E8D4A2" :name "Hampton" :shade "Yellow")
                      (make-ntc--struct :code "#5218FA" :name "Han Purple" :shade "Violet")
                      (make-ntc--struct :code "#3FFF00" :name "Harlequin" :shade "Green")
                      (make-ntc--struct :code "#C93413" :name "Harley Davidson Orange" :shade "Orange")
                      (make-ntc--struct :code "#CBCEC0" :name "Harp" :shade "Green")
                      (make-ntc--struct :code "#EAB76A" :name "Harvest Gold" :shade "Yellow")
                      (make-ntc--struct :code "#3B2B2C" :name "Havana" :shade "Brown")
                      (make-ntc--struct :code "#5784C1" :name "Havelock Blue" :shade "Blue")
                      (make-ntc--struct :code "#99522B" :name "Hawaiian Tan" :shade "Orange")
                      (make-ntc--struct :code "#D2DAED" :name "Hawkes Blue" :shade "Blue")
                      (make-ntc--struct :code "#4F2A2C" :name "Heath" :shade "Red")
                      (make-ntc--struct :code "#AEBBC1" :name "Heather" :shade "Blue")
                      (make-ntc--struct :code "#948C7E" :name "Heathered Grey" :shade "Brown")
                      (make-ntc--struct :code "#46473E" :name "Heavy Metal" :shade "Grey")
                      (make-ntc--struct :code "#DF73FF" :name "Heliotrope" :shade "Violet")
                      (make-ntc--struct :code "#69684B" :name "Hemlock" :shade "Yellow")
                      (make-ntc--struct :code "#987D73" :name "Hemp" :shade "Brown")
                      (make-ntc--struct :code "#928C3C" :name "Highball" :shade "Green")
                      (make-ntc--struct :code "#7A9461" :name "Highland" :shade "Green")
                      (make-ntc--struct :code "#A7A07E" :name "Hillary" :shade "Green")
                      (make-ntc--struct :code "#736330" :name "Himalaya" :shade "Yellow")
                      (make-ntc--struct :code "#DFF1D6" :name "Hint Of Green" :shade "Green")
                      (make-ntc--struct :code "#F5EFEB" :name "Hint Of Red" :shade "Grey")
                      (make-ntc--struct :code "#F6F5D7" :name "Hint Of Yellow" :shade "Green")
                      (make-ntc--struct :code "#49889A" :name "Hippie Blue" :shade "Blue")
                      (make-ntc--struct :code "#608A5A" :name "Hippie Green" :shade "Green")
                      (make-ntc--struct :code "#AB495C" :name "Hippie Pink" :shade "Red")
                      (make-ntc--struct :code "#A1A9A8" :name "Hit Grey" :shade "Grey")
                      (make-ntc--struct :code "#FDA470" :name "Hit Pink" :shade "Orange")
                      (make-ntc--struct :code "#BB8E34" :name "Hokey Pokey" :shade "Yellow")
                      (make-ntc--struct :code "#647D86" :name "Hoki" :shade "Blue")
                      (make-ntc--struct :code "#25342B" :name "Holly" :shade "Green")
                      (make-ntc--struct :code "#F400A1" :name "Hollywood Cerise" :shade "Red")
                      (make-ntc--struct :code "#5C3C6D" :name "Honey Flower" :shade "Violet")
                      (make-ntc--struct :code "#F0FFF0" :name "Honeydew" :shade "White")
                      (make-ntc--struct :code "#E8ED69" :name "Honeysuckle" :shade "Green")
                      (make-ntc--struct :code "#CD6D93" :name "Hopbush" :shade "Violet")
                      (make-ntc--struct :code "#648894" :name "Horizon" :shade "Blue")
                      (make-ntc--struct :code "#6D562C" :name "Horses Neck" :shade "Yellow")
                      (make-ntc--struct :code "#815B28" :name "Hot Curry" :shade "Yellow")
                      (make-ntc--struct :code "#FF00CC" :name "Hot Magenta" :shade "Red")
                      (make-ntc--struct :code "#FF69B4" :name "Hot Pink" :shade "Red")
                      (make-ntc--struct :code "#4E2E53" :name "Hot Purple" :shade "Violet")
                      (make-ntc--struct :code "#A7752C" :name "Hot Toddy" :shade "Yellow")
                      (make-ntc--struct :code "#CEEFE4" :name "Humming Bird" :shade "Green")
                      (make-ntc--struct :code "#355E3B" :name "Hunter Green" :shade "Green")
                      (make-ntc--struct :code "#8B7E77" :name "Hurricane" :shade "Brown")
                      (make-ntc--struct :code "#B2994B" :name "Husk" :shade "Yellow")
                      (make-ntc--struct :code "#AFE3D6" :name "Ice Cold" :shade "Green")
                      (make-ntc--struct :code "#CAE1D9" :name "Iceberg" :shade "Green")
                      (make-ntc--struct :code "#EF95AE" :name "Illusion" :shade "Red")
                      (make-ntc--struct :code "#B0E313" :name "Inch Worm" :shade "Green")
                      (make-ntc--struct :code "#CD5C5C" :name "Indian Red" :shade "Red")
                      (make-ntc--struct :code "#4F301F" :name "Indian Tan" :shade "Brown")
                      (make-ntc--struct :code "#4B0082" :name "Indigo" :shade "Violet")
                      (make-ntc--struct :code "#9C5B34" :name "Indochine" :shade "Orange")
                      (make-ntc--struct :code "#002FA7" :name "International Klein Blue" :shade "Blue")
                      (make-ntc--struct :code "#FF4F00" :name "International Orange" :shade "Orange")
                      (make-ntc--struct :code "#03B4C8" :name "Iris Blue" :shade "Blue")
                      (make-ntc--struct :code "#62422B" :name "Irish Coffee" :shade "Brown")
                      (make-ntc--struct :code "#CBCDCD" :name "Iron" :shade "Grey")
                      (make-ntc--struct :code "#706E66" :name "Ironside Grey" :shade "Grey")
                      (make-ntc--struct :code "#865040" :name "Ironstone" :shade "Brown")
                      (make-ntc--struct :code "#009900" :name "Islamic Green" :shade "Green")
                      (make-ntc--struct :code "#F8EDDB" :name "Island Spice" :shade "Yellow")
                      (make-ntc--struct :code "#FFFFF0" :name "Ivory" :shade "White")
                      (make-ntc--struct :code "#3D325D" :name "Jacarta" :shade "Violet")
                      (make-ntc--struct :code "#413628" :name "Jacko Bean" :shade "Brown")
                      (make-ntc--struct :code "#3D3F7D" :name "Jacksons Purple" :shade "Violet")
                      (make-ntc--struct :code "#00A86B" :name "Jade" :shade "Green")
                      (make-ntc--struct :code "#E27945" :name "Jaffa" :shade "Orange")
                      (make-ntc--struct :code "#CAE7E2" :name "Jagged Ice" :shade "Green")
                      (make-ntc--struct :code "#3F2E4C" :name "Jagger" :shade "Violet")
                      (make-ntc--struct :code "#29292F" :name "Jaguar" :shade "Blue")
                      (make-ntc--struct :code "#674834" :name "Jambalaya" :shade "Brown")
                      (make-ntc--struct :code "#2F7532" :name "Japanese Laurel" :shade "Green")
                      (make-ntc--struct :code "#CE7259" :name "Japonica" :shade "Orange")
                      (make-ntc--struct :code "#259797" :name "Java" :shade "Green")
                      (make-ntc--struct :code "#5F2C2F" :name "Jazz" :shade "Red")
                      (make-ntc--struct :code "#A50B5E" :name "Jazzberry Jam" :shade "Red")
                      (make-ntc--struct :code "#44798E" :name "Jelly Bean" :shade "Blue")
                      (make-ntc--struct :code "#BBD0C9" :name "Jet Stream" :shade "Green")
                      (make-ntc--struct :code "#136843" :name "Jewel" :shade "Green")
                      (make-ntc--struct :code "#463D3E" :name "Jon" :shade "Grey")
                      (make-ntc--struct :code "#EEF293" :name "Jonquil" :shade "Green")
                      (make-ntc--struct :code "#7AAAE0" :name "Jordy Blue" :shade "Blue")
                      (make-ntc--struct :code "#5D5346" :name "Judge Grey" :shade "Brown")
                      (make-ntc--struct :code "#878785" :name "Jumbo" :shade "Grey")
                      (make-ntc--struct :code "#29AB87" :name "Jungle Green" :shade "Green")
                      (make-ntc--struct :code "#B0C4C4" :name "Jungle Mist" :shade "Green")
                      (make-ntc--struct :code "#74918E" :name "Juniper" :shade "Green")
                      (make-ntc--struct :code "#DCBFAC" :name "Just Right" :shade "Orange")
                      (make-ntc--struct :code "#6C5E53" :name "Kabul" :shade "Brown")
                      (make-ntc--struct :code "#245336" :name "Kaitoke Green" :shade "Green")
                      (make-ntc--struct :code "#C5C3B0" :name "Kangaroo" :shade "Green")
                      (make-ntc--struct :code "#2D2D24" :name "Karaka" :shade "Green")
                      (make-ntc--struct :code "#FEDCC1" :name "Karry" :shade "Orange")
                      (make-ntc--struct :code "#576D8E" :name "Kashmir Blue" :shade "Blue")
                      (make-ntc--struct :code "#4CBB17" :name "Kelly Green" :shade "Green")
                      (make-ntc--struct :code "#4D503C" :name "Kelp" :shade "Green")
                      (make-ntc--struct :code "#6C322E" :name "Kenyan Copper" :shade "Red")
                      (make-ntc--struct :code "#5FB69C" :name "Keppel" :shade "Green")
                      (make-ntc--struct :code "#F0E68C" :name "Khaki" :shade "Yellow")
                      (make-ntc--struct :code "#BFC0AB" :name "Kidnapper" :shade "Green")
                      (make-ntc--struct :code "#3A3532" :name "Kilamanjaro" :shade "Grey")
                      (make-ntc--struct :code "#49764F" :name "Killarney" :shade "Green")
                      (make-ntc--struct :code "#695D87" :name "Kimberly" :shade "Violet")
                      (make-ntc--struct :code "#583580" :name "Kingfisher Daisy" :shade "Violet")
                      (make-ntc--struct :code "#E093AB" :name "Kobi" :shade "Red")
                      (make-ntc--struct :code "#7B785A" :name "Kokoda" :shade "Green")
                      (make-ntc--struct :code "#804E2C" :name "Korma" :shade "Orange")
                      (make-ntc--struct :code "#FEB552" :name "Koromiko" :shade "Yellow")
                      (make-ntc--struct :code "#F9D054" :name "Kournikova" :shade "Yellow")
                      (make-ntc--struct :code "#428929" :name "La Palma" :shade "Green")
                      (make-ntc--struct :code "#BAC00E" :name "La Rioja" :shade "Green")
                      (make-ntc--struct :code "#C6DA36" :name "Las Palmas" :shade "Green")
                      (make-ntc--struct :code "#C6A95E" :name "Laser" :shade "Yellow")
                      (make-ntc--struct :code "#FFFF66" :name "Laser Lemon" :shade "Yellow")
                      (make-ntc--struct :code "#6E8D71" :name "Laurel" :shade "Green")
                      (make-ntc--struct :code "#E6E6FA" :name "Lavender" :shade "Violet")
                      (make-ntc--struct :code "#CCCCFF" :name "Lavender Blue" :shade "Blue")
                      (make-ntc--struct :code "#FFF0F5" :name "Lavender Blush" :shade "Violet")
                      (make-ntc--struct :code "#BDBBD7" :name "Lavender Grey" :shade "Grey")
                      (make-ntc--struct :code "#FBAED2" :name "Lavender Pink" :shade "Red")
                      (make-ntc--struct :code "#FBA0E3" :name "Lavender Rose" :shade "Red")
                      (make-ntc--struct :code "#7CFC00" :name "Lawn Green" :shade "Green")
                      (make-ntc--struct :code "#906A54" :name "Leather" :shade "Brown")
                      (make-ntc--struct :code "#FDE910" :name "Lemon" :shade "Yellow")
                      (make-ntc--struct :code "#FFFACD" :name "Lemon Chiffon" :shade "Yellow")
                      (make-ntc--struct :code "#968428" :name "Lemon Ginger" :shade "Yellow")
                      (make-ntc--struct :code "#999A86" :name "Lemon Grass" :shade "Green")
                      (make-ntc--struct :code "#2E3749" :name "Licorice" :shade "Blue")
                      (make-ntc--struct :code "#ADD8E6" :name "Light Blue" :shade "Blue")
                      (make-ntc--struct :code "#F08080" :name "Light Coral" :shade "Orange")
                      (make-ntc--struct :code "#E0FFFF" :name "Light Cyan" :shade "Blue")
                      (make-ntc--struct :code "#EEDD82" :name "Light Goldenrod" :shade "Yellow")
                      (make-ntc--struct :code "#FAFAD2" :name "Light Goldenrod Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#90EE90" :name "Light Green" :shade "Green")
                      (make-ntc--struct :code "#D3D3D3" :name "Light Grey" :shade "Grey")
                      (make-ntc--struct :code "#FFB6C1" :name "Light Pink" :shade "Red")
                      (make-ntc--struct :code "#FFA07A" :name "Light Salmon" :shade "Orange")
                      (make-ntc--struct :code "#20B2AA" :name "Light Sea Green" :shade "Green")
                      (make-ntc--struct :code "#87CEFA" :name "Light Sky Blue" :shade "Blue")
                      (make-ntc--struct :code "#8470FF" :name "Light Slate Blue" :shade "Blue")
                      (make-ntc--struct :code "#778899" :name "Light Slate Grey" :shade "Grey")
                      (make-ntc--struct :code "#B0C4DE" :name "Light Steel Blue" :shade "Blue")
                      (make-ntc--struct :code "#856363" :name "Light Wood" :shade "Brown")
                      (make-ntc--struct :code "#FFFFE0" :name "Light Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#F7A233" :name "Lightning Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#C8A2C8" :name "Lilac" :shade "Violet")
                      (make-ntc--struct :code "#9470C4" :name "Lilac Bush" :shade "Violet")
                      (make-ntc--struct :code "#C19FB3" :name "Lily" :shade "Violet")
                      (make-ntc--struct :code "#E9EEEB" :name "Lily White" :shade "Grey")
                      (make-ntc--struct :code "#7AAC21" :name "Lima" :shade "Green")
                      (make-ntc--struct :code "#00FF00" :name "Lime" :shade "Green")
                      (make-ntc--struct :code "#32CD32" :name "Lime Green" :shade "Green")
                      (make-ntc--struct :code "#5F9727" :name "Limeade" :shade "Green")
                      (make-ntc--struct :code "#89AC27" :name "Limerick" :shade "Green")
                      (make-ntc--struct :code "#FAF0E6" :name "Linen" :shade "White")
                      (make-ntc--struct :code "#C7CDD8" :name "Link Water" :shade "Blue")
                      (make-ntc--struct :code "#962C54" :name "Lipstick" :shade "Red")
                      (make-ntc--struct :code "#534B4F" :name "Liver" :shade "Brown")
                      (make-ntc--struct :code "#312A29" :name "Livid Brown" :shade "Brown")
                      (make-ntc--struct :code "#DBD9C2" :name "Loafer" :shade "Green")
                      (make-ntc--struct :code "#B3BBB7" :name "Loblolly" :shade "Green")
                      (make-ntc--struct :code "#489084" :name "Lochinvar" :shade "Green")
                      (make-ntc--struct :code "#316EA0" :name "Lochmara" :shade "Blue")
                      (make-ntc--struct :code "#A2A580" :name "Locust" :shade "Green")
                      (make-ntc--struct :code "#393E2E" :name "Log Cabin" :shade "Green")
                      (make-ntc--struct :code "#9D9CB4" :name "Logan" :shade "Blue")
                      (make-ntc--struct :code "#B9ACBB" :name "Lola" :shade "Violet")
                      (make-ntc--struct :code "#AE94AB" :name "London Hue" :shade "Violet")
                      (make-ntc--struct :code "#522426" :name "Lonestar" :shade "Red")
                      (make-ntc--struct :code "#8B504B" :name "Lotus" :shade "Brown")
                      (make-ntc--struct :code "#4C3347" :name "Loulou" :shade "Violet")
                      (make-ntc--struct :code "#AB9A1C" :name "Lucky" :shade "Green")
                      (make-ntc--struct :code "#292D4F" :name "Lucky Point" :shade "Blue")
                      (make-ntc--struct :code "#4E5541" :name "Lunar Green" :shade "Green")
                      (make-ntc--struct :code "#782E2C" :name "Lusty" :shade "Red")
                      (make-ntc--struct :code "#AB8D3F" :name "Luxor Gold" :shade "Yellow")
                      (make-ntc--struct :code "#697D89" :name "Lynch" :shade "Blue")
                      (make-ntc--struct :code "#CBE8E8" :name "Mabel" :shade "Blue")
                      (make-ntc--struct :code "#FFB97B" :name "Macaroni And Cheese" :shade "Orange")
                      (make-ntc--struct :code "#B7E3A8" :name "Madang" :shade "Green")
                      (make-ntc--struct :code "#2D3C54" :name "Madison" :shade "Blue")
                      (make-ntc--struct :code "#473E23" :name "Madras" :shade "Brown")
                      (make-ntc--struct :code "#FF00FF" :name "Magenta" :shade "Violet")
                      (make-ntc--struct :code "#AAF0D1" :name "Magic Mint" :shade "Green")
                      (make-ntc--struct :code "#F8F4FF" :name "Magnolia" :shade "White")
                      (make-ntc--struct :code "#CA3435" :name "Mahogany" :shade "Brown")
                      (make-ntc--struct :code "#A56531" :name "Mai Tai" :shade "Orange")
                      (make-ntc--struct :code "#2A2922" :name "Maire" :shade "Yellow")
                      (make-ntc--struct :code "#E3B982" :name "Maize" :shade "Yellow")
                      (make-ntc--struct :code "#695F50" :name "Makara" :shade "Brown")
                      (make-ntc--struct :code "#505555" :name "Mako" :shade "Grey")
                      (make-ntc--struct :code "#0BDA51" :name "Malachite" :shade "Green")
                      (make-ntc--struct :code "#97976F" :name "Malachite Green" :shade "Green")
                      (make-ntc--struct :code "#66B7E1" :name "Malibu" :shade "Blue")
                      (make-ntc--struct :code "#3A4531" :name "Mallard" :shade "Green")
                      (make-ntc--struct :code "#A59784" :name "Malta" :shade "Brown")
                      (make-ntc--struct :code "#766D7C" :name "Mamba" :shade "Violet")
                      (make-ntc--struct :code "#8D90A1" :name "Manatee" :shade "Blue")
                      (make-ntc--struct :code "#B57B2E" :name "Mandalay" :shade "Yellow")
                      (make-ntc--struct :code "#8E2323" :name "Mandarian Orange" :shade "Orange")
                      (make-ntc--struct :code "#CD525B" :name "Mandy" :shade "Red")
                      (make-ntc--struct :code "#F5B799" :name "Mandys Pink" :shade "Orange")
                      (make-ntc--struct :code "#E77200" :name "Mango Tango" :shade "Orange")
                      (make-ntc--struct :code "#E2AF80" :name "Manhattan" :shade "Orange")
                      (make-ntc--struct :code "#7FC15C" :name "Mantis" :shade "Green")
                      (make-ntc--struct :code "#96A793" :name "Mantle" :shade "Green")
                      (make-ntc--struct :code "#E4DB55" :name "Manz" :shade "Green")
                      (make-ntc--struct :code "#352235" :name "Mardi Gras" :shade "Violet")
                      (make-ntc--struct :code "#B88A3D" :name "Marigold" :shade "Yellow")
                      (make-ntc--struct :code "#42639F" :name "Mariner" :shade "Blue")
                      (make-ntc--struct :code "#800000" :name "Maroon" :shade "Brown")
                      (make-ntc--struct :code "#2B2E26" :name "Marshland" :shade "Green")
                      (make-ntc--struct :code "#B7A8A3" :name "Martini" :shade "Brown")
                      (make-ntc--struct :code "#3C3748" :name "Martinique" :shade "Violet")
                      (make-ntc--struct :code "#EBC881" :name "Marzipan" :shade "Yellow")
                      (make-ntc--struct :code "#57534B" :name "Masala" :shade "Brown")
                      (make-ntc--struct :code "#365C7D" :name "Matisse" :shade "Blue")
                      (make-ntc--struct :code "#8E4D45" :name "Matrix" :shade "Red")
                      (make-ntc--struct :code "#524B4B" :name "Matterhorn" :shade "Grey")
                      (make-ntc--struct :code "#E0B0FF" :name "Mauve" :shade "Violet")
                      (make-ntc--struct :code "#915F6D" :name "Mauve Taupe" :shade "Red")
                      (make-ntc--struct :code "#F091A9" :name "Mauvelous" :shade "Red")
                      (make-ntc--struct :code "#C8B1C0" :name "Maverick" :shade "Violet")
                      (make-ntc--struct :code "#73C2FB" :name "Maya Blue" :shade "Blue")
                      (make-ntc--struct :code "#8C6338" :name "McKenzie" :shade "Orange")
                      (make-ntc--struct :code "#66CDAA" :name "Medium Aquamarine" :shade "Blue")
                      (make-ntc--struct :code "#0000CD" :name "Medium Blue" :shade "Blue")
                      (make-ntc--struct :code "#AF4035" :name "Medium Carmine" :shade "Red")
                      (make-ntc--struct :code "#EAEAAE" :name "Medium Goldenrod" :shade "Yellow")
                      (make-ntc--struct :code "#BA55D3" :name "Medium Orchid" :shade "Violet")
                      (make-ntc--struct :code "#9370DB" :name "Medium Purple" :shade "Violet")
                      (make-ntc--struct :code "#3CB371" :name "Medium Sea Green" :shade "Green")
                      (make-ntc--struct :code "#7B68EE" :name "Medium Slate Blue" :shade "Blue")
                      (make-ntc--struct :code "#00FA9A" :name "Medium Spring Green" :shade "Green")
                      (make-ntc--struct :code "#48D1CC" :name "Medium Turquoise" :shade "Blue")
                      (make-ntc--struct :code "#C71585" :name "Medium Violet Red" :shade "Red")
                      (make-ntc--struct :code "#A68064" :name "Medium Wood" :shade "Brown")
                      (make-ntc--struct :code "#E0B7C2" :name "Melanie" :shade "Red")
                      (make-ntc--struct :code "#342931" :name "Melanzane" :shade "Violet")
                      (make-ntc--struct :code "#FEBAAD" :name "Melon" :shade "Red")
                      (make-ntc--struct :code "#C3B9DD" :name "Melrose" :shade "Violet")
                      (make-ntc--struct :code "#D5D2D1" :name "Mercury" :shade "Grey")
                      (make-ntc--struct :code "#E1DBD0" :name "Merino" :shade "Yellow")
                      (make-ntc--struct :code "#4F4E48" :name "Merlin" :shade "Grey")
                      (make-ntc--struct :code "#73343A" :name "Merlot" :shade "Red")
                      (make-ntc--struct :code "#554A3C" :name "Metallic Bronze" :shade "Red")
                      (make-ntc--struct :code "#6E3D34" :name "Metallic Copper" :shade "Red")
                      (make-ntc--struct :code "#D4AF37" :name "Metallic Gold" :shade "Yellow")
                      (make-ntc--struct :code "#BB7431" :name "Meteor" :shade "Orange")
                      (make-ntc--struct :code "#4A3B6A" :name "Meteorite" :shade "Violet")
                      (make-ntc--struct :code "#9B3D3D" :name "Mexican Red" :shade "Red")
                      (make-ntc--struct :code "#666A6D" :name "Mid Grey" :shade "Grey")
                      (make-ntc--struct :code "#21303E" :name "Midnight" :shade "Blue")
                      (make-ntc--struct :code "#191970" :name "Midnight Blue" :shade "Blue")
                      (make-ntc--struct :code "#21263A" :name "Midnight Express" :shade "Blue")
                      (make-ntc--struct :code "#242E28" :name "Midnight Moss" :shade "Green")
                      (make-ntc--struct :code "#3F3623" :name "Mikado" :shade "Brown")
                      (make-ntc--struct :code "#F6F493" :name "Milan" :shade "Green")
                      (make-ntc--struct :code "#9E3332" :name "Milano Red" :shade "Red")
                      (make-ntc--struct :code "#F3E5C0" :name "Milk Punch" :shade "Yellow")
                      (make-ntc--struct :code "#DCD9CD" :name "Milk White" :shade "Grey")
                      (make-ntc--struct :code "#595648" :name "Millbrook" :shade "Brown")
                      (make-ntc--struct :code "#F5F5CC" :name "Mimosa" :shade "Green")
                      (make-ntc--struct :code "#DAEA6F" :name "Mindaro" :shade "Green")
                      (make-ntc--struct :code "#373E41" :name "Mine Shaft" :shade "Blue")
                      (make-ntc--struct :code "#506355" :name "Mineral Green" :shade "Green")
                      (make-ntc--struct :code "#407577" :name "Ming" :shade "Green")
                      (make-ntc--struct :code "#3E3267" :name "Minsk" :shade "Violet")
                      (make-ntc--struct :code "#F5FFFA" :name "Mint Cream" :shade "White")
                      (make-ntc--struct :code "#98FF98" :name "Mint Green" :shade "Green")
                      (make-ntc--struct :code "#E0D8A7" :name "Mint Julep" :shade "Green")
                      (make-ntc--struct :code "#C6EADD" :name "Mint Tulip" :shade "Green")
                      (make-ntc--struct :code "#373F43" :name "Mirage" :shade "Blue")
                      (make-ntc--struct :code "#A5A9B2" :name "Mischka" :shade "Blue")
                      (make-ntc--struct :code "#BAB9A9" :name "Mist Grey" :shade "Grey")
                      (make-ntc--struct :code "#FFE4E1" :name "Misty Rose" :shade "Violet")
                      (make-ntc--struct :code "#605A67" :name "Mobster" :shade "Violet")
                      (make-ntc--struct :code "#582F2B" :name "Moccaccino" :shade "Red")
                      (make-ntc--struct :code "#FFE4B5" :name "Moccasin" :shade "Yellow")
                      (make-ntc--struct :code "#6F372D" :name "Mocha" :shade "Red")
                      (make-ntc--struct :code "#97463C" :name "Mojo" :shade "Red")
                      (make-ntc--struct :code "#FF9889" :name "Mona Lisa" :shade "Red")
                      (make-ntc--struct :code "#6B252C" :name "Monarch" :shade "Red")
                      (make-ntc--struct :code "#554D42" :name "Mondo" :shade "Brown")
                      (make-ntc--struct :code "#A58B6F" :name "Mongoose" :shade "Brown")
                      (make-ntc--struct :code "#7A7679" :name "Monsoon" :shade "Grey")
                      (make-ntc--struct :code "#393B3C" :name "Montana" :shade "Grey")
                      (make-ntc--struct :code "#7AC5B4" :name "Monte Carlo" :shade "Green")
                      (make-ntc--struct :code "#8378C7" :name "Moody Blue" :shade "Violet")
                      (make-ntc--struct :code "#F5F3CE" :name "Moon Glow" :shade "Green")
                      (make-ntc--struct :code "#CECDB8" :name "Moon Mist" :shade "Green")
                      (make-ntc--struct :code "#C0B2D7" :name "Moon Raker" :shade "Violet")
                      (make-ntc--struct :code "#F0C420" :name "Moon Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#9ED1D3" :name "Morning Glory" :shade "Blue")
                      (make-ntc--struct :code "#442D21" :name "Morocco Brown" :shade "Brown")
                      (make-ntc--struct :code "#565051" :name "Mortar" :shade "Grey")
                      (make-ntc--struct :code "#005F5B" :name "Mosque" :shade "Green")
                      (make-ntc--struct :code "#ADDFAD" :name "Moss Green" :shade "Green")
                      (make-ntc--struct :code "#1AB385" :name "Mountain Meadow" :shade "Green")
                      (make-ntc--struct :code "#A09F9C" :name "Mountain Mist" :shade "Grey")
                      (make-ntc--struct :code "#997A8D" :name "Mountbatten Pink" :shade "Violet")
                      (make-ntc--struct :code "#A9844F" :name "Muddy Waters" :shade "Yellow")
                      (make-ntc--struct :code "#9E7E53" :name "Muesli" :shade "Brown")
                      (make-ntc--struct :code "#C54B8C" :name "Mulberry" :shade "Violet")
                      (make-ntc--struct :code "#884F40" :name "Mule Fawn" :shade "Brown")
                      (make-ntc--struct :code "#524D5B" :name "Mulled Wine" :shade "Violet")
                      (make-ntc--struct :code "#FFDB58" :name "Mustard" :shade "Yellow")
                      (make-ntc--struct :code "#D68B80" :name "My Pink" :shade "Red")
                      (make-ntc--struct :code "#FDAE45" :name "My Sin" :shade "Yellow")
                      (make-ntc--struct :code "#21421E" :name "Myrtle" :shade "Green")
                      (make-ntc--struct :code "#D8DDDA" :name "Mystic" :shade "Grey")
                      (make-ntc--struct :code "#4E5D4E" :name "Nandor" :shade "Green")
                      (make-ntc--struct :code "#A39A87" :name "Napa" :shade "Yellow")
                      (make-ntc--struct :code "#E9E6DC" :name "Narvik" :shade "Green")
                      (make-ntc--struct :code "#FFDEAD" :name "Navajo White" :shade "Brown")
                      (make-ntc--struct :code "#000080" :name "Navy" :shade "Blue")
                      (make-ntc--struct :code "#0066CC" :name "Navy Blue" :shade "Blue")
                      (make-ntc--struct :code "#B8C6BE" :name "Nebula" :shade "Green")
                      (make-ntc--struct :code "#EEC7A2" :name "Negroni" :shade "Orange")
                      (make-ntc--struct :code "#4D4DFF" :name "Neon Blue" :shade "Blue")
                      (make-ntc--struct :code "#FF9933" :name "Neon Carrot" :shade "Orange")
                      (make-ntc--struct :code "#FF6EC7" :name "Neon Pink" :shade "Violet")
                      (make-ntc--struct :code "#93AAB9" :name "Nepal" :shade "Blue")
                      (make-ntc--struct :code "#77A8AB" :name "Neptune" :shade "Green")
                      (make-ntc--struct :code "#252525" :name "Nero" :shade "Grey")
                      (make-ntc--struct :code "#AAA583" :name "Neutral Green" :shade "Green")
                      (make-ntc--struct :code "#666F6F" :name "Nevada" :shade "Grey")
                      (make-ntc--struct :code "#6D3B24" :name "New Amber" :shade "Orange")
                      (make-ntc--struct :code "#00009C" :name "New Midnight Blue" :shade "Blue")
                      (make-ntc--struct :code "#E4C385" :name "New Orleans" :shade "Yellow")
                      (make-ntc--struct :code "#EBC79E" :name "New Tan" :shade "Brown")
                      (make-ntc--struct :code "#DD8374" :name "New York Pink" :shade "Red")
                      (make-ntc--struct :code "#29A98B" :name "Niagara" :shade "Green")
                      (make-ntc--struct :code "#332E2E" :name "Night Rider" :shade "Grey")
                      (make-ntc--struct :code "#A23D54" :name "Night Shadz" :shade "Red")
                      (make-ntc--struct :code "#253F4E" :name "Nile Blue" :shade "Blue")
                      (make-ntc--struct :code "#A99D9D" :name "Nobel" :shade "Grey")
                      (make-ntc--struct :code "#A19986" :name "Nomad" :shade "Yellow")
                      (make-ntc--struct :code "#1D393C" :name "Nordic" :shade "Blue")
                      (make-ntc--struct :code "#A4B88F" :name "Norway" :shade "Green")
                      (make-ntc--struct :code "#BC9229" :name "Nugget" :shade "Yellow")
                      (make-ntc--struct :code "#7E4A3B" :name "Nutmeg" :shade "Brown")
                      (make-ntc--struct :code "#FCEDC5" :name "Oasis" :shade "Yellow")
                      (make-ntc--struct :code "#008F70" :name "Observatory" :shade "Green")
                      (make-ntc--struct :code "#4CA973" :name "Ocean Green" :shade "Green")
                      (make-ntc--struct :code "#CC7722" :name "Ochre" :shade "Brown")
                      (make-ntc--struct :code "#DFF0E2" :name "Off Green" :shade "Green")
                      (make-ntc--struct :code "#FAF3DC" :name "Off Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#313330" :name "Oil" :shade "Grey")
                      (make-ntc--struct :code "#8A3335" :name "Old Brick" :shade "Red")
                      (make-ntc--struct :code "#73503B" :name "Old Copper" :shade "Red")
                      (make-ntc--struct :code "#CFB53B" :name "Old Gold" :shade "Yellow")
                      (make-ntc--struct :code "#FDF5E6" :name "Old Lace" :shade "White")
                      (make-ntc--struct :code "#796878" :name "Old Lavender" :shade "Violet")
                      (make-ntc--struct :code "#C02E4C" :name "Old Rose" :shade "Red")
                      (make-ntc--struct :code "#808000" :name "Olive" :shade "Green")
                      (make-ntc--struct :code "#6B8E23" :name "Olive Drab" :shade "Green")
                      (make-ntc--struct :code "#B5B35C" :name "Olive Green" :shade "Green")
                      (make-ntc--struct :code "#888064" :name "Olive Haze" :shade "Yellow")
                      (make-ntc--struct :code "#747028" :name "Olivetone" :shade "Green")
                      (make-ntc--struct :code "#9AB973" :name "Olivine" :shade "Orange")
                      (make-ntc--struct :code "#C2E6EC" :name "Onahau" :shade "Blue")
                      (make-ntc--struct :code "#48412B" :name "Onion" :shade "Yellow")
                      (make-ntc--struct :code "#A8C3BC" :name "Opal" :shade "Green")
                      (make-ntc--struct :code "#987E7E" :name "Opium" :shade "Brown")
                      (make-ntc--struct :code "#395555" :name "Oracle" :shade "Green")
                      (make-ntc--struct :code "#FFA500" :name "Orange" :shade "Orange")
                      (make-ntc--struct :code "#FFA000" :name "Orange Peel" :shade "Orange")
                      (make-ntc--struct :code "#FF4500" :name "Orange Red" :shade "Orange")
                      (make-ntc--struct :code "#A85335" :name "Orange Roughy" :shade "Orange")
                      (make-ntc--struct :code "#EAE3CD" :name "Orange White" :shade "Yellow")
                      (make-ntc--struct :code "#DA70D6" :name "Orchid" :shade "Violet")
                      (make-ntc--struct :code "#F1EBD9" :name "Orchid White" :shade "Yellow")
                      (make-ntc--struct :code "#255B77" :name "Orient" :shade "Blue")
                      (make-ntc--struct :code "#C28E88" :name "Oriental Pink" :shade "Red")
                      (make-ntc--struct :code "#D2D3B3" :name "Orinoco" :shade "Green")
                      (make-ntc--struct :code "#818988" :name "Oslo Grey" :shade "Grey")
                      (make-ntc--struct :code "#D3DBCB" :name "Ottoman" :shade "Green")
                      (make-ntc--struct :code "#2D383A" :name "Outer Space" :shade "Grey")
                      (make-ntc--struct :code "#FF6037" :name "Outrageous Orange" :shade "Orange")
                      (make-ntc--struct :code "#28353A" :name "Oxford Blue" :shade "Blue")
                      (make-ntc--struct :code "#6D9A78" :name "Oxley" :shade "Green")
                      (make-ntc--struct :code "#D1EAEA" :name "Oyster Bay" :shade "Blue")
                      (make-ntc--struct :code "#D4B5B0" :name "Oyster Pink" :shade "Red")
                      (make-ntc--struct :code "#864B36" :name "Paarl" :shade "Orange")
                      (make-ntc--struct :code "#7A715C" :name "Pablo" :shade "Yellow")
                      (make-ntc--struct :code "#009DC4" :name "Pacific Blue" :shade "Blue")
                      (make-ntc--struct :code "#4F4037" :name "Paco" :shade "Brown")
                      (make-ntc--struct :code "#7EB394" :name "Padua" :shade "Green")
                      (make-ntc--struct :code "#682860" :name "Palatinate Purple" :shade "Violet")
                      (make-ntc--struct :code "#987654" :name "Pale Brown" :shade "Brown")
                      (make-ntc--struct :code "#DDADAF" :name "Pale Chestnut" :shade "Red")
                      (make-ntc--struct :code "#ABCDEF" :name "Pale Cornflower Blue" :shade "Blue")
                      (make-ntc--struct :code "#EEE8AA" :name "Pale Goldenrod" :shade "Yellow")
                      (make-ntc--struct :code "#98FB98" :name "Pale Green" :shade "Green")
                      (make-ntc--struct :code "#BDCAA8" :name "Pale Leaf" :shade "Green")
                      (make-ntc--struct :code "#F984E5" :name "Pale Magenta" :shade "Violet")
                      (make-ntc--struct :code "#9C8D72" :name "Pale Oyster" :shade "Brown")
                      (make-ntc--struct :code "#FADADD" :name "Pale Pink" :shade "Red")
                      (make-ntc--struct :code "#F9F59F" :name "Pale Prim" :shade "Green")
                      (make-ntc--struct :code "#EFD6DA" :name "Pale Rose" :shade "Red")
                      (make-ntc--struct :code "#636D70" :name "Pale Sky" :shade "Blue")
                      (make-ntc--struct :code "#C3BEBB" :name "Pale Slate" :shade "Grey")
                      (make-ntc--struct :code "#BC987E" :name "Pale Taupe" :shade "Grey")
                      (make-ntc--struct :code "#AFEEEE" :name "Pale Turquoise" :shade "Blue")
                      (make-ntc--struct :code "#DB7093" :name "Pale Violet Red" :shade "Red")
                      (make-ntc--struct :code "#20392C" :name "Palm Green" :shade "Green")
                      (make-ntc--struct :code "#36482F" :name "Palm Leaf" :shade "Green")
                      (make-ntc--struct :code "#EAE4DC" :name "Pampas" :shade "Grey")
                      (make-ntc--struct :code "#EBF7E4" :name "Panache" :shade "Green")
                      (make-ntc--struct :code "#DFB992" :name "Pancho" :shade "Orange")
                      (make-ntc--struct :code "#544F3A" :name "Panda" :shade "Yellow")
                      (make-ntc--struct :code "#FFEFD5" :name "Papaya Whip" :shade "Yellow")
                      (make-ntc--struct :code "#7C2D37" :name "Paprika" :shade "Red")
                      (make-ntc--struct :code "#488084" :name "Paradiso" :shade "Green")
                      (make-ntc--struct :code "#D0C8B0" :name "Parchment" :shade "Yellow")
                      (make-ntc--struct :code "#FBEB50" :name "Paris Daisy" :shade "Green")
                      (make-ntc--struct :code "#312760" :name "Paris M" :shade "Violet")
                      (make-ntc--struct :code "#BFCDC0" :name "Paris White" :shade "Green")
                      (make-ntc--struct :code "#305D35" :name "Parsley" :shade "Green")
                      (make-ntc--struct :code "#77DD77" :name "Pastel Green" :shade "Green")
                      (make-ntc--struct :code "#639283" :name "Patina" :shade "Green")
                      (make-ntc--struct :code "#D3E5EF" :name "Pattens Blue" :shade "Blue")
                      (make-ntc--struct :code "#2A2551" :name "Paua" :shade "Violet")
                      (make-ntc--struct :code "#BAAB87" :name "Pavlova" :shade "Yellow")
                      (make-ntc--struct :code "#404048" :name "Payne's Grey" :shade "Grey")
                      (make-ntc--struct :code "#FFCBA4" :name "Peach" :shade "Orange")
                      (make-ntc--struct :code "#FFDAB9" :name "Peach Puff" :shade "Yellow")
                      (make-ntc--struct :code "#FFCC99" :name "Peach-Orange" :shade "Orange")
                      (make-ntc--struct :code "#FADFAD" :name "Peach-Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#7A4434" :name "Peanut" :shade "Brown")
                      (make-ntc--struct :code "#D1E231" :name "Pear" :shade "Yellow")
                      (make-ntc--struct :code "#DED1C6" :name "Pearl Bush" :shade "Orange")
                      (make-ntc--struct :code "#EAE0C8" :name "Pearl Lusta" :shade "Yellow")
                      (make-ntc--struct :code "#766D52" :name "Peat" :shade "Yellow")
                      (make-ntc--struct :code "#2599B2" :name "Pelorous" :shade "Blue")
                      (make-ntc--struct :code "#D7E7D0" :name "Peppermint" :shade "Green")
                      (make-ntc--struct :code "#ACB9E8" :name "Perano" :shade "Blue")
                      (make-ntc--struct :code "#C2A9DB" :name "Perfume" :shade "Violet")
                      (make-ntc--struct :code "#ACB6B2" :name "Periglacial Blue" :shade "Green")
                      (make-ntc--struct :code "#C3CDE6" :name "Periwinkle" :shade "Blue")
                      (make-ntc--struct :code "#1C39BB" :name "Persian Blue" :shade "Blue")
                      (make-ntc--struct :code "#00A693" :name "Persian Green" :shade "Green")
                      (make-ntc--struct :code "#32127A" :name "Persian Indigo" :shade "Violet")
                      (make-ntc--struct :code "#F77FBE" :name "Persian Pink" :shade "Red")
                      (make-ntc--struct :code "#683332" :name "Persian Plum" :shade "Red")
                      (make-ntc--struct :code "#CC3333" :name "Persian Red" :shade "Red")
                      (make-ntc--struct :code "#FE28A2" :name "Persian Rose" :shade "Red")
                      (make-ntc--struct :code "#EC5800" :name "Persimmon" :shade "Red")
                      (make-ntc--struct :code "#CD853F" :name "Peru" :shade "Brown")
                      (make-ntc--struct :code "#733D1F" :name "Peru Tan" :shade "Orange")
                      (make-ntc--struct :code "#7A7229" :name "Pesto" :shade "Yellow")
                      (make-ntc--struct :code "#DA9790" :name "Petite Orchid" :shade "Red")
                      (make-ntc--struct :code "#91A092" :name "Pewter" :shade "Green")
                      (make-ntc--struct :code "#826663" :name "Pharlap" :shade "Brown")
                      (make-ntc--struct :code "#F8EA97" :name "Picasso" :shade "Green")
                      (make-ntc--struct :code "#5BA0D0" :name "Picton Blue" :shade "Blue")
                      (make-ntc--struct :code "#FDD7E4" :name "Pig Pink" :shade "Red")
                      (make-ntc--struct :code "#00A550" :name "Pigment Green" :shade "Green")
                      (make-ntc--struct :code "#756556" :name "Pine Cone" :shade "Brown")
                      (make-ntc--struct :code "#BDC07E" :name "Pine Glade" :shade "Green")
                      (make-ntc--struct :code "#01796F" :name "Pine Green" :shade "Green")
                      (make-ntc--struct :code "#2A2F23" :name "Pine Tree" :shade "Green")
                      (make-ntc--struct :code "#FFC0CB" :name "Pink" :shade "Red")
                      (make-ntc--struct :code "#FF66FF" :name "Pink Flamingo" :shade "Red")
                      (make-ntc--struct :code "#D8B4B6" :name "Pink Flare" :shade "Red")
                      (make-ntc--struct :code "#F6CCD7" :name "Pink Lace" :shade "Red")
                      (make-ntc--struct :code "#F3D7B6" :name "Pink Lady" :shade "Orange")
                      (make-ntc--struct :code "#BFB3B2" :name "Pink Swan" :shade "Grey")
                      (make-ntc--struct :code "#9D5432" :name "Piper" :shade "Orange")
                      (make-ntc--struct :code "#F5E6C4" :name "Pipi" :shade "Yellow")
                      (make-ntc--struct :code "#FCDBD2" :name "Pippin" :shade "Red")
                      (make-ntc--struct :code "#BA782A" :name "Pirate Gold" :shade "Yellow")
                      (make-ntc--struct :code "#BBCDA5" :name "Pixie Green" :shade "Green")
                      (make-ntc--struct :code "#E57F3D" :name "Pizazz" :shade "Orange")
                      (make-ntc--struct :code "#BF8D3C" :name "Pizza" :shade "Yellow")
                      (make-ntc--struct :code "#3E594C" :name "Plantation" :shade "Green")
                      (make-ntc--struct :code "#DDA0DD" :name "Plum" :shade "Violet")
                      (make-ntc--struct :code "#651C26" :name "Pohutukawa" :shade "Red")
                      (make-ntc--struct :code "#E5F2E7" :name "Polar" :shade "Green")
                      (make-ntc--struct :code "#8AA7CC" :name "Polo Blue" :shade "Blue")
                      (make-ntc--struct :code "#6A1F44" :name "Pompadour" :shade "Violet")
                      (make-ntc--struct :code "#DDDCDB" :name "Porcelain" :shade "Grey")
                      (make-ntc--struct :code "#DF9D5B" :name "Porsche" :shade "Orange")
                      (make-ntc--struct :code "#3B436C" :name "Port Gore" :shade "Blue")
                      (make-ntc--struct :code "#F4F09B" :name "Portafino" :shade "Green")
                      (make-ntc--struct :code "#8B98D8" :name "Portage" :shade "Blue")
                      (make-ntc--struct :code "#F0D555" :name "Portica" :shade "Yellow")
                      (make-ntc--struct :code "#EFDCD4" :name "Pot Pourri" :shade "Orange")
                      (make-ntc--struct :code "#845C40" :name "Potters Clay" :shade "Brown")
                      (make-ntc--struct :code "#B0E0E6" :name "Powder Blue" :shade "Blue")
                      (make-ntc--struct :code "#883C32" :name "Prairie Sand" :shade "Red")
                      (make-ntc--struct :code "#CAB4D4" :name "Prelude" :shade "Violet")
                      (make-ntc--struct :code "#E2CDD5" :name "Prim" :shade "Violet")
                      (make-ntc--struct :code "#E4DE8E" :name "Primrose" :shade "Green")
                      (make-ntc--struct :code "#F8F6DF" :name "Promenade" :shade "Green")
                      (make-ntc--struct :code "#F6E3DA" :name "Provincial Pink" :shade "Orange")
                      (make-ntc--struct :code "#003366" :name "Prussian Blue" :shade "Blue")
                      (make-ntc--struct :code "#DD00FF" :name "Psychedelic Purple" :shade "Violet")
                      (make-ntc--struct :code "#CC8899" :name "Puce" :shade "Red")
                      (make-ntc--struct :code "#6E3326" :name "Pueblo" :shade "Orange")
                      (make-ntc--struct :code "#59BAA3" :name "Puerto Rico" :shade "Green")
                      (make-ntc--struct :code "#BAC0B4" :name "Pumice" :shade "Green")
                      (make-ntc--struct :code "#FF7518" :name "Pumpkin" :shade "Orange")
                      (make-ntc--struct :code "#534931" :name "Punga" :shade "Yellow")
                      (make-ntc--struct :code "#800080" :name "Purple" :shade "Violet")
                      (make-ntc--struct :code "#652DC1" :name "Purple Heart" :shade "Violet")
                      (make-ntc--struct :code "#9678B6" :name "Purple Mountain's Majesty" :shade "Violet")
                      (make-ntc--struct :code "#50404D" :name "Purple Taupe" :shade "Grey")
                      (make-ntc--struct :code "#CDAE70" :name "Putty" :shade "Yellow")
                      (make-ntc--struct :code "#F2EDDD" :name "Quarter Pearl Lusta" :shade "Green")
                      (make-ntc--struct :code "#EBE2D2" :name "Quarter Spanish White" :shade "Yellow")
                      (make-ntc--struct :code "#D9D9F3" :name "Quartz" :shade "White")
                      (make-ntc--struct :code "#C3988B" :name "Quicksand" :shade "Brown")
                      (make-ntc--struct :code "#CBC9C0" :name "Quill Grey" :shade "Grey")
                      (make-ntc--struct :code "#6A5445" :name "Quincy" :shade "Brown")
                      (make-ntc--struct :code "#232F2C" :name "Racing Green" :shade "Green")
                      (make-ntc--struct :code "#FF355E" :name "Radical Red" :shade "Red")
                      (make-ntc--struct :code "#DCC6A0" :name "Raffia" :shade "Yellow")
                      (make-ntc--struct :code "#667028" :name "Rain Forest" :shade "Green")
                      (make-ntc--struct :code "#B3C1B1" :name "Rainee" :shade "Green")
                      (make-ntc--struct :code "#FCAE60" :name "Rajah" :shade "Orange")
                      (make-ntc--struct :code "#2B2E25" :name "Rangoon Green" :shade "Green")
                      (make-ntc--struct :code "#6F747B" :name "Raven" :shade "Blue")
                      (make-ntc--struct :code "#D27D46" :name "Raw Sienna" :shade "Brown")
                      (make-ntc--struct :code "#734A12" :name "Raw Umber" :shade "Brown")
                      (make-ntc--struct :code "#FF33CC" :name "Razzle Dazzle Rose" :shade "Red")
                      (make-ntc--struct :code "#E30B5C" :name "Razzmatazz" :shade "Red")
                      (make-ntc--struct :code "#453430" :name "Rebel" :shade "Brown")
                      (make-ntc--struct :code "#FF0000" :name "Red" :shade "Red")
                      (make-ntc--struct :code "#701F28" :name "Red Berry" :shade "Red")
                      (make-ntc--struct :code "#CB6F4A" :name "Red Damask" :shade "Orange")
                      (make-ntc--struct :code "#662A2C" :name "Red Devil" :shade "Red")
                      (make-ntc--struct :code "#FF3F34" :name "Red Orange" :shade "Orange")
                      (make-ntc--struct :code "#5D1F1E" :name "Red Oxide" :shade "Red")
                      (make-ntc--struct :code "#7D4138" :name "Red Robin" :shade "Red")
                      (make-ntc--struct :code "#AD522E" :name "Red Stage" :shade "Orange")
                      (make-ntc--struct :code "#BB3385" :name "Medium Red Violet" :shade "Violet")
                      (make-ntc--struct :code "#5B342E" :name "Redwood" :shade "Red")
                      (make-ntc--struct :code "#D1EF9F" :name "Reef" :shade "Green")
                      (make-ntc--struct :code "#A98D36" :name "Reef Gold" :shade "Yellow")
                      (make-ntc--struct :code "#203F58" :name "Regal Blue" :shade "Blue")
                      (make-ntc--struct :code "#798488" :name "Regent Grey" :shade "Blue")
                      (make-ntc--struct :code "#A0CDD9" :name "Regent St Blue" :shade "Blue")
                      (make-ntc--struct :code "#F6DEDA" :name "Remy" :shade "Red")
                      (make-ntc--struct :code "#B26E33" :name "Reno Sand" :shade "Orange")
                      (make-ntc--struct :code "#323F75" :name "Resolution Blue" :shade "Blue")
                      (make-ntc--struct :code "#37363F" :name "Revolver" :shade "Violet")
                      (make-ntc--struct :code "#3D4653" :name "Rhino" :shade "Blue")
                      (make-ntc--struct :code "#EFECDE" :name "Rice Cake" :shade "Green")
                      (make-ntc--struct :code "#EFF5D1" :name "Rice Flower" :shade "Green")
                      (make-ntc--struct :code "#5959AB" :name "Rich Blue" :shade "Blue")
                      (make-ntc--struct :code "#A15226" :name "Rich Gold" :shade "Orange")
                      (make-ntc--struct :code "#B7C61A" :name "Rio Grande" :shade "Green")
                      (make-ntc--struct :code "#89D9C8" :name "Riptide" :shade "Green")
                      (make-ntc--struct :code "#556061" :name "River Bed" :shade "Blue")
                      (make-ntc--struct :code "#DDAD56" :name "Rob Roy" :shade "Yellow")
                      (make-ntc--struct :code "#00CCCC" :name "Robin's Egg Blue" :shade "Blue")
                      (make-ntc--struct :code "#5A4D41" :name "Rock" :shade "Brown")
                      (make-ntc--struct :code "#93A2BA" :name "Rock Blue" :shade "Blue")
                      (make-ntc--struct :code "#9D442D" :name "Rock Spray" :shade "Orange")
                      (make-ntc--struct :code "#C7A384" :name "Rodeo Dust" :shade "Brown")
                      (make-ntc--struct :code "#6D7876" :name "Rolling Stone" :shade "Green")
                      (make-ntc--struct :code "#D8625B" :name "Roman" :shade "Red")
                      (make-ntc--struct :code "#7D6757" :name "Roman Coffee" :shade "Brown")
                      (make-ntc--struct :code "#F4F0E6" :name "Romance" :shade "Grey")
                      (make-ntc--struct :code "#FFC69E" :name "Romantic" :shade "Orange")
                      (make-ntc--struct :code "#EAB852" :name "Ronchi" :shade "Yellow")
                      (make-ntc--struct :code "#A14743" :name "Roof Terracotta" :shade "Red")
                      (make-ntc--struct :code "#8E593C" :name "Rope" :shade "Orange")
                      (make-ntc--struct :code "#D3A194" :name "Rose" :shade "Red")
                      (make-ntc--struct :code "#FEAB9A" :name "Rose Bud" :shade "Red")
                      (make-ntc--struct :code "#8A2D52" :name "Rose Bud Cherry" :shade "Red")
                      (make-ntc--struct :code "#AC512D" :name "Rose Of Sharon" :shade "Orange")
                      (make-ntc--struct :code "#905D5D" :name "Rose Taupe" :shade "Violet")
                      (make-ntc--struct :code "#FBEEE8" :name "Rose White" :shade "Red")
                      (make-ntc--struct :code "#BC8F8F" :name "Rosy Brown" :shade "Brown")
                      (make-ntc--struct :code "#B69642" :name "Roti" :shade "Yellow")
                      (make-ntc--struct :code "#A94064" :name "Rouge" :shade "Red")
                      (make-ntc--struct :code "#4169E1" :name "Royal Blue" :shade "Blue")
                      (make-ntc--struct :code "#B54B73" :name "Royal Heath" :shade "Red")
                      (make-ntc--struct :code "#6B3FA0" :name "Royal Purple" :shade "Violet")
                      (make-ntc--struct :code "#E0115F" :name "Ruby" :shade "Red")
                      (make-ntc--struct :code "#716675" :name "Rum" :shade "Violet")
                      (make-ntc--struct :code "#F1EDD4" :name "Rum Swizzle" :shade "Green")
                      (make-ntc--struct :code "#80461B" :name "Russet" :shade "Brown")
                      (make-ntc--struct :code "#7D655C" :name "Russett" :shade "Brown")
                      (make-ntc--struct :code "#B7410E" :name "Rust" :shade "Red")
                      (make-ntc--struct :code "#3A181A" :name "Rustic Red" :shade "Red")
                      (make-ntc--struct :code "#8D5F2C" :name "Rusty Nail" :shade "Orange")
                      (make-ntc--struct :code "#5D4E46" :name "Saddle" :shade "Brown")
                      (make-ntc--struct :code "#8B4513" :name "Saddle Brown" :shade "Brown")
                      (make-ntc--struct :code "#FF6600" :name "Safety Orange" :shade "Orange")
                      (make-ntc--struct :code "#F4C430" :name "Saffron" :shade "Yellow")
                      (make-ntc--struct :code "#989F7A" :name "Sage" :shade "Green")
                      (make-ntc--struct :code "#B79826" :name "Sahara" :shade "Yellow")
                      (make-ntc--struct :code "#A5CEEC" :name "Sail" :shade "Blue")
                      (make-ntc--struct :code "#177B4D" :name "Salem" :shade "Green")
                      (make-ntc--struct :code "#FA8072" :name "Salmon" :shade "Red")
                      (make-ntc--struct :code "#FFD67B" :name "Salomie" :shade "Yellow")
                      (make-ntc--struct :code "#696268" :name "Salt Box" :shade "Violet")
                      (make-ntc--struct :code "#EEF3E5" :name "Saltpan" :shade "Grey")
                      (make-ntc--struct :code "#3B2E25" :name "Sambuca" :shade "Brown")
                      (make-ntc--struct :code "#2C6E31" :name "San Felix" :shade "Green")
                      (make-ntc--struct :code "#445761" :name "San Juan" :shade "Blue")
                      (make-ntc--struct :code "#4E6C9D" :name "San Marino" :shade "Blue")
                      (make-ntc--struct :code "#867665" :name "Sand Dune" :shade "Brown")
                      (make-ntc--struct :code "#A3876A" :name "Sandal" :shade "Brown")
                      (make-ntc--struct :code "#AF937D" :name "Sandrift" :shade "Brown")
                      (make-ntc--struct :code "#786D5F" :name "Sandstone" :shade "Brown")
                      (make-ntc--struct :code "#DECB81" :name "Sandwisp" :shade "Yellow")
                      (make-ntc--struct :code "#FEDBB7" :name "Sandy Beach" :shade "Orange")
                      (make-ntc--struct :code "#F4A460" :name "Sandy Brown" :shade "Brown")
                      (make-ntc--struct :code "#92000A" :name "Sangria" :shade "Red")
                      (make-ntc--struct :code "#6C3736" :name "Sanguine Brown" :shade "Red")
                      (make-ntc--struct :code "#9998A7" :name "Santas Grey" :shade "Blue")
                      (make-ntc--struct :code "#A96A50" :name "Sante Fe" :shade "Orange")
                      (make-ntc--struct :code "#E1D5A6" :name "Sapling" :shade "Yellow")
                      (make-ntc--struct :code "#082567" :name "Sapphire" :shade "Blue")
                      (make-ntc--struct :code "#555B2C" :name "Saratoga" :shade "Green")
                      (make-ntc--struct :code "#F4EAE4" :name "Sauvignon" :shade "Red")
                      (make-ntc--struct :code "#F5DEC4" :name "Sazerac" :shade "Orange")
                      (make-ntc--struct :code "#6F63A0" :name "Scampi" :shade "Violet")
                      (make-ntc--struct :code "#ADD9D1" :name "Scandal" :shade "Green")
                      (make-ntc--struct :code "#FF2400" :name "Scarlet" :shade "Red")
                      (make-ntc--struct :code "#4A2D57" :name "Scarlet Gum" :shade "Violet")
                      (make-ntc--struct :code "#7E2530" :name "Scarlett" :shade "Red")
                      (make-ntc--struct :code "#6B6A6C" :name "Scarpa Flow" :shade "Grey")
                      (make-ntc--struct :code "#87876F" :name "Schist" :shade "Green")
                      (make-ntc--struct :code "#FFD800" :name "School Bus Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#8D8478" :name "Schooner" :shade "Brown")
                      (make-ntc--struct :code "#308EA0" :name "Scooter" :shade "Blue")
                      (make-ntc--struct :code "#6A6466" :name "Scorpion" :shade "Grey")
                      (make-ntc--struct :code "#EEE7C8" :name "Scotch Mist" :shade "Yellow")
                      (make-ntc--struct :code "#66FF66" :name "Screamin' Green" :shade "Green")
                      (make-ntc--struct :code "#3D4031" :name "Scrub" :shade "Green")
                      (make-ntc--struct :code "#EF9548" :name "Sea Buckthorn" :shade "Orange")
                      (make-ntc--struct :code "#DFDDD6" :name "Sea Fog" :shade "Grey")
                      (make-ntc--struct :code "#2E8B57" :name "Sea Green" :shade "Green")
                      (make-ntc--struct :code "#C2D5C4" :name "Sea Mist" :shade "Green")
                      (make-ntc--struct :code "#8AAEA4" :name "Sea Nymph" :shade "Green")
                      (make-ntc--struct :code "#DB817E" :name "Sea Pink" :shade "Red")
                      (make-ntc--struct :code "#77B7D0" :name "Seagull" :shade "Blue")
                      (make-ntc--struct :code "#321414" :name "Seal Brown" :shade "Brown")
                      (make-ntc--struct :code "#69326E" :name "Seance" :shade "Violet")
                      (make-ntc--struct :code "#FFF5EE" :name "Seashell" :shade "White")
                      (make-ntc--struct :code "#37412A" :name "Seaweed" :shade "Green")
                      (make-ntc--struct :code "#E6DFE7" :name "Selago" :shade "Violet")
                      (make-ntc--struct :code "#FFBA00" :name "Selective Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#6B4226" :name "Semi-Sweet Chocolate" :shade "Brown")
                      (make-ntc--struct :code "#9E5B40" :name "Sepia" :shade "Brown")
                      (make-ntc--struct :code "#FCE9D7" :name "Serenade" :shade "Orange")
                      (make-ntc--struct :code "#837050" :name "Shadow" :shade "Green")
                      (make-ntc--struct :code "#9AC0B6" :name "Shadow Green" :shade "Green")
                      (make-ntc--struct :code "#9F9B9D" :name "Shady Lady" :shade "Grey")
                      (make-ntc--struct :code "#609AB8" :name "Shakespeare" :shade "Blue")
                      (make-ntc--struct :code "#F8F6A8" :name "Shalimar" :shade "Green")
                      (make-ntc--struct :code "#33CC99" :name "Shamrock" :shade "Green")
                      (make-ntc--struct :code "#009E60" :name "Shamrock Green" :shade "Green")
                      (make-ntc--struct :code "#34363A" :name "Shark" :shade "Grey")
                      (make-ntc--struct :code "#00494E" :name "Sherpa Blue" :shade "Green")
                      (make-ntc--struct :code "#1B4636" :name "Sherwood Green" :shade "Green")
                      (make-ntc--struct :code "#E6B2A6" :name "Shilo" :shade "Red")
                      (make-ntc--struct :code "#745937" :name "Shingle Fawn" :shade "Brown")
                      (make-ntc--struct :code "#7988AB" :name "Ship Cove" :shade "Blue")
                      (make-ntc--struct :code "#4E4E4C" :name "Ship Grey" :shade "Grey")
                      (make-ntc--struct :code "#842833" :name "Shiraz" :shade "Red")
                      (make-ntc--struct :code "#E899BE" :name "Shocking" :shade "Violet")
                      (make-ntc--struct :code "#FC0FC0" :name "Shocking Pink" :shade "Red")
                      (make-ntc--struct :code "#61666B" :name "Shuttle Grey" :shade "Grey")
                      (make-ntc--struct :code "#686B50" :name "Siam" :shade "Green")
                      (make-ntc--struct :code "#E9D9A9" :name "Sidecar" :shade "Yellow")
                      (make-ntc--struct :code "#A0522D" :name "Sienna" :shade "Brown")
                      (make-ntc--struct :code "#BBADA1" :name "Silk" :shade "Brown")
                      (make-ntc--struct :code "#C0C0C0" :name "Silver" :shade "Grey")
                      (make-ntc--struct :code "#ACAEA9" :name "Silver Chalice" :shade "Grey")
                      (make-ntc--struct :code "#BEBDB6" :name "Silver Sand" :shade "Grey")
                      (make-ntc--struct :code "#67BE90" :name "Silver Tree" :shade "Green")
                      (make-ntc--struct :code "#A6D5D0" :name "Sinbad" :shade "Green")
                      (make-ntc--struct :code "#69293B" :name "Siren" :shade "Red")
                      (make-ntc--struct :code "#68766E" :name "Sirocco" :shade "Green")
                      (make-ntc--struct :code "#C5BAA0" :name "Sisal" :shade "Yellow")
                      (make-ntc--struct :code "#9DB4AA" :name "Skeptic" :shade "Green")
                      (make-ntc--struct :code "#87CEEB" :name "Sky Blue" :shade "Blue")
                      (make-ntc--struct :code "#6A5ACD" :name "Slate Blue" :shade "Blue")
                      (make-ntc--struct :code "#708090" :name "Slate Grey" :shade "Grey")
                      (make-ntc--struct :code "#42342B" :name "Slugger" :shade "Brown")
                      (make-ntc--struct :code "#003399" :name "Smalt" :shade "Blue")
                      (make-ntc--struct :code "#496267" :name "Smalt Blue" :shade "Blue")
                      (make-ntc--struct :code "#BB5F34" :name "Smoke Tree" :shade "Orange")
                      (make-ntc--struct :code "#605D6B" :name "Smoky" :shade "Violet")
                      (make-ntc--struct :code "#FFFAFA" :name "Snow" :shade "White")
                      (make-ntc--struct :code "#E3E3DC" :name "Snow Drift" :shade "Grey")
                      (make-ntc--struct :code "#EAF7C9" :name "Snow Flurry" :shade "Green")
                      (make-ntc--struct :code "#D6F0CD" :name "Snowy Mint" :shade "Green")
                      (make-ntc--struct :code "#E4D7E5" :name "Snuff" :shade "Violet")
                      (make-ntc--struct :code "#ECE5DA" :name "Soapstone" :shade "Grey")
                      (make-ntc--struct :code "#CFBEA5" :name "Soft Amber" :shade "Yellow")
                      (make-ntc--struct :code "#EEDFDE" :name "Soft Peach" :shade "Red")
                      (make-ntc--struct :code "#85494C" :name "Solid Pink" :shade "Red")
                      (make-ntc--struct :code "#EADAC2" :name "Solitaire" :shade "Yellow")
                      (make-ntc--struct :code "#E9ECF1" :name "Solitude" :shade "Blue")
                      (make-ntc--struct :code "#DD6B38" :name "Sorbus" :shade "Orange")
                      (make-ntc--struct :code "#9D7F61" :name "Sorrell Brown" :shade "Brown")
                      (make-ntc--struct :code "#C9B59A" :name "Sour Dough" :shade "Brown")
                      (make-ntc--struct :code "#6F634B" :name "Soya Bean" :shade "Brown")
                      (make-ntc--struct :code "#4B433B" :name "Space Shuttle" :shade "Brown")
                      (make-ntc--struct :code "#7B8976" :name "Spanish Green" :shade "Green")
                      (make-ntc--struct :code "#DED1B7" :name "Spanish White" :shade "Yellow")
                      (make-ntc--struct :code "#375D4F" :name "Spectra" :shade "Green")
                      (make-ntc--struct :code "#6C4F3F" :name "Spice" :shade "Brown")
                      (make-ntc--struct :code "#8B5F4D" :name "Spicy Mix" :shade "Brown")
                      (make-ntc--struct :code "#FF1CAE" :name "Spicy Pink" :shade "Red")
                      (make-ntc--struct :code "#B3C4D8" :name "Spindle" :shade "Blue")
                      (make-ntc--struct :code "#F1D79E" :name "Splash" :shade "Yellow")
                      (make-ntc--struct :code "#7ECDDD" :name "Spray" :shade "Blue")
                      (make-ntc--struct :code "#A7FC00" :name "Spring Bud" :shade "Green")
                      (make-ntc--struct :code "#00FF7F" :name "Spring Green" :shade "Green")
                      (make-ntc--struct :code "#A3BD9C" :name "Spring Rain" :shade "Green")
                      (make-ntc--struct :code "#F1F1C6" :name "Spring Sun" :shade "Green")
                      (make-ntc--struct :code "#E9E1D9" :name "Spring Wood" :shade "Grey")
                      (make-ntc--struct :code "#B8CA9D" :name "Sprout" :shade "Green")
                      (make-ntc--struct :code "#A2A1AC" :name "Spun Pearl" :shade "Blue")
                      (make-ntc--struct :code "#8F7D6B" :name "Squirrel" :shade "Brown")
                      (make-ntc--struct :code "#325482" :name "St Tropaz" :shade "Blue")
                      (make-ntc--struct :code "#858885" :name "Stack" :shade "Grey")
                      (make-ntc--struct :code "#A0A197" :name "Star Dust" :shade "Grey")
                      (make-ntc--struct :code "#D2C6B6" :name "Stark White" :shade "Yellow")
                      (make-ntc--struct :code "#E3DD39" :name "Starship" :shade "Green")
                      (make-ntc--struct :code "#4682B4" :name "Steel Blue" :shade "Blue")
                      (make-ntc--struct :code "#43464B" :name "Steel Grey" :shade "Grey")
                      (make-ntc--struct :code "#833D3E" :name "Stiletto" :shade "Red")
                      (make-ntc--struct :code "#807661" :name "Stonewall" :shade "Yellow")
                      (make-ntc--struct :code "#65645F" :name "Storm Dust" :shade "Grey")
                      (make-ntc--struct :code "#747880" :name "Storm Grey" :shade "Blue")
                      (make-ntc--struct :code "#DABE82" :name "Straw" :shade "Yellow")
                      (make-ntc--struct :code "#946A81" :name "Strikemaster" :shade "Violet")
                      (make-ntc--struct :code "#406356" :name "Stromboli" :shade "Green")
                      (make-ntc--struct :code "#724AA1" :name "Studio" :shade "Violet")
                      (make-ntc--struct :code "#8C9C9C" :name "Submarine" :shade "Blue")
                      (make-ntc--struct :code "#EEEFDF" :name "Sugar Cane" :shade "Green")
                      (make-ntc--struct :code "#C6EA80" :name "Sulu" :shade "Green")
                      (make-ntc--struct :code "#8FB69C" :name "Summer Green" :shade "Green")
                      (make-ntc--struct :code "#38B0DE" :name "Summer Sky" :shade "Blue")
                      (make-ntc--struct :code "#EF8E38" :name "Sun" :shade "Orange")
                      (make-ntc--struct :code "#C4AA4D" :name "Sundance" :shade "Yellow")
                      (make-ntc--struct :code "#F8AFA9" :name "Sundown" :shade "Red")
                      (make-ntc--struct :code "#DAC01A" :name "Sunflower" :shade "Yellow")
                      (make-ntc--struct :code "#C76155" :name "Sunglo" :shade "Red")
                      (make-ntc--struct :code "#FFCC33" :name "Sunglow" :shade "Orange")
                      (make-ntc--struct :code "#C0514A" :name "Sunset" :shade "Red")
                      (make-ntc--struct :code "#FE4C40" :name "Sunset Orange" :shade "Orange")
                      (make-ntc--struct :code "#FA9D49" :name "Sunshade" :shade "Orange")
                      (make-ntc--struct :code "#FFB437" :name "Supernova" :shade "Yellow")
                      (make-ntc--struct :code "#B8D4BB" :name "Surf" :shade "Green")
                      (make-ntc--struct :code "#C3D6BD" :name "Surf Crest" :shade "Green")
                      (make-ntc--struct :code "#007B77" :name "Surfie Green" :shade "Green")
                      (make-ntc--struct :code "#7C9F2F" :name "Sushi" :shade "Green")
                      (make-ntc--struct :code "#8B8685" :name "Suva Grey" :shade "Grey")
                      (make-ntc--struct :code "#252F2F" :name "Swamp" :shade "Green")
                      (make-ntc--struct :code "#DAE6DD" :name "Swans Down" :shade "Grey")
                      (make-ntc--struct :code "#F9E176" :name "Sweet Corn" :shade "Yellow")
                      (make-ntc--struct :code "#EE918D" :name "Sweet Pink" :shade "Red")
                      (make-ntc--struct :code "#D7CEC5" :name "Swirl" :shade "Grey")
                      (make-ntc--struct :code "#DBD0CA" :name "Swiss Coffee" :shade "Grey")
                      (make-ntc--struct :code "#F6AE78" :name "Tacao" :shade "Orange")
                      (make-ntc--struct :code "#D2B960" :name "Tacha" :shade "Yellow")
                      (make-ntc--struct :code "#DC722A" :name "Tahiti Gold" :shade "Orange")
                      (make-ntc--struct :code "#D8CC9B" :name "Tahuna Sands" :shade "Yellow")
                      (make-ntc--struct :code "#853534" :name "Tall Poppy" :shade "Red")
                      (make-ntc--struct :code "#A39977" :name "Tallow" :shade "Yellow")
                      (make-ntc--struct :code "#752B2F" :name "Tamarillo" :shade "Red")
                      (make-ntc--struct :code "#D2B48C" :name "Tan" :shade "Brown")
                      (make-ntc--struct :code "#B8B5A1" :name "Tana" :shade "Green")
                      (make-ntc--struct :code "#1E2F3C" :name "Tangaroa" :shade "Blue")
                      (make-ntc--struct :code "#F28500" :name "Tangerine" :shade "Orange")
                      (make-ntc--struct :code "#FFCC00" :name "Tangerine Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#D46F31" :name "Tango" :shade "Orange")
                      (make-ntc--struct :code "#7C7C72" :name "Tapa" :shade "Green")
                      (make-ntc--struct :code "#B37084" :name "Tapestry" :shade "Red")
                      (make-ntc--struct :code "#DEF1DD" :name "Tara" :shade "Green")
                      (make-ntc--struct :code "#253C48" :name "Tarawera" :shade "Blue")
                      (make-ntc--struct :code "#BAC0B3" :name "Tasman" :shade "Grey")
                      (make-ntc--struct :code "#483C32" :name "Taupe" :shade "Grey")
                      (make-ntc--struct :code "#8B8589" :name "Taupe Grey" :shade "Grey")
                      (make-ntc--struct :code "#643A48" :name "Tawny Port" :shade "Red")
                      (make-ntc--struct :code "#496569" :name "Tax Break" :shade "Blue")
                      (make-ntc--struct :code "#2B4B40" :name "Te Papa Green" :shade "Green")
                      (make-ntc--struct :code "#BFB5A2" :name "Tea" :shade "Yellow")
                      (make-ntc--struct :code "#D0F0C0" :name "Tea Green" :shade "Green")
                      (make-ntc--struct :code "#F883C2" :name "Tea Rose" :shade "Orange")
                      (make-ntc--struct :code "#AB8953" :name "Teak" :shade "Yellow")
                      (make-ntc--struct :code "#008080" :name "Teal" :shade "Blue")
                      (make-ntc--struct :code "#254855" :name "Teal Blue" :shade "Blue")
                      (make-ntc--struct :code "#3C2126" :name "Temptress" :shade "Brown")
                      (make-ntc--struct :code "#CD5700" :name "Tenne (Tawny)" :shade "Orange")
                      (make-ntc--struct :code "#F4D0A4" :name "Tequila" :shade "Yellow")
                      (make-ntc--struct :code "#E2725B" :name "Terra Cotta" :shade "Red")
                      (make-ntc--struct :code "#ECE67E" :name "Texas" :shade "Green")
                      (make-ntc--struct :code "#FCB057" :name "Texas Rose" :shade "Orange")
                      (make-ntc--struct :code "#B1948F" :name "Thatch" :shade "Brown")
                      (make-ntc--struct :code "#544E31" :name "Thatch Green" :shade "Yellow")
                      (make-ntc--struct :code "#D8BFD8" :name "Thistle" :shade "Violet")
                      (make-ntc--struct :code "#4D4D4B" :name "Thunder" :shade "Grey")
                      (make-ntc--struct :code "#923830" :name "Thunderbird" :shade "Red")
                      (make-ntc--struct :code "#97422D" :name "Tia Maria" :shade "Orange")
                      (make-ntc--struct :code "#B9C3BE" :name "Tiara" :shade "Grey")
                      (make-ntc--struct :code "#184343" :name "Tiber" :shade "Green")
                      (make-ntc--struct :code "#FC80A5" :name "Tickle Me Pink" :shade "Red")
                      (make-ntc--struct :code "#F0F590" :name "Tidal" :shade "Green")
                      (make-ntc--struct :code "#BEB4AB" :name "Tide" :shade "Brown")
                      (make-ntc--struct :code "#324336" :name "Timber Green" :shade "Green")
                      (make-ntc--struct :code "#D9D6CF" :name "Timberwolf" :shade "Grey")
                      (make-ntc--struct :code "#DDD6E1" :name "Titan White" :shade "Violet")
                      (make-ntc--struct :code "#9F715F" :name "Toast" :shade "Brown")
                      (make-ntc--struct :code "#6D5843" :name "Tobacco Brown" :shade "Brown")
                      (make-ntc--struct :code "#44362D" :name "Tobago" :shade "Brown")
                      (make-ntc--struct :code "#3E2631" :name "Toledo" :shade "Violet")
                      (make-ntc--struct :code "#2D2541" :name "Tolopea" :shade "Violet")
                      (make-ntc--struct :code "#4F6348" :name "Tom Thumb" :shade "Green")
                      (make-ntc--struct :code "#FF6347" :name "Tomato" :shade "Red")
                      (make-ntc--struct :code "#E79E88" :name "Tonys Pink" :shade "Orange")
                      (make-ntc--struct :code "#817C87" :name "Topaz" :shade "Violet")
                      (make-ntc--struct :code "#FD0E35" :name "Torch Red" :shade "Red")
                      (make-ntc--struct :code "#353D75" :name "Torea Bay" :shade "Blue")
                      (make-ntc--struct :code "#374E88" :name "Tory Blue" :shade "Blue")
                      (make-ntc--struct :code "#744042" :name "Tosca" :shade "Red")
                      (make-ntc--struct :code "#9CACA5" :name "Tower Grey" :shade "Green")
                      (make-ntc--struct :code "#6DAFA7" :name "Tradewind" :shade "Green")
                      (make-ntc--struct :code "#DDEDE9" :name "Tranquil" :shade "Blue")
                      (make-ntc--struct :code "#E2DDC7" :name "Travertine" :shade "Green")
                      (make-ntc--struct :code "#E2813B" :name "Tree Poppy" :shade "Orange")
                      (make-ntc--struct :code "#7E8424" :name "Trendy Green" :shade "Green")
                      (make-ntc--struct :code "#805D80" :name "Trendy Pink" :shade "Violet")
                      (make-ntc--struct :code "#C54F33" :name "Trinidad" :shade "Orange")
                      (make-ntc--struct :code "#AEC9EB" :name "Tropical Blue" :shade "Blue")
                      (make-ntc--struct :code "#00755E" :name "Tropical Rain Forest" :shade "Green")
                      (make-ntc--struct :code "#4C5356" :name "Trout" :shade "Grey")
                      (make-ntc--struct :code "#8E72C7" :name "True V" :shade "Violet")
                      (make-ntc--struct :code "#454642" :name "Tuatara" :shade "Grey")
                      (make-ntc--struct :code "#F9D3BE" :name "Tuft Bush" :shade "Orange")
                      (make-ntc--struct :code "#E3AC3D" :name "Tulip Tree" :shade "Yellow")
                      (make-ntc--struct :code "#DEA681" :name "Tumbleweed" :shade "Brown")
                      (make-ntc--struct :code "#46494E" :name "Tuna" :shade "Grey")
                      (make-ntc--struct :code "#585452" :name "Tundora" :shade "Grey")
                      (make-ntc--struct :code "#F5CC23" :name "Turbo" :shade "Yellow")
                      (make-ntc--struct :code "#A56E75" :name "Turkish Rose" :shade "Red")
                      (make-ntc--struct :code "#AE9041" :name "Turmeric" :shade "Yellow")
                      (make-ntc--struct :code "#40E0D0" :name "Turquoise" :shade "Blue")
                      (make-ntc--struct :code "#6CDAE7" :name "Turquoise Blue" :shade "Blue")
                      (make-ntc--struct :code "#363E1D" :name "Turtle Green" :shade "Green")
                      (make-ntc--struct :code "#AD6242" :name "Tuscany" :shade "Orange")
                      (make-ntc--struct :code "#E3E5B1" :name "Tusk" :shade "Green")
                      (make-ntc--struct :code "#BF914B" :name "Tussock" :shade "Yellow")
                      (make-ntc--struct :code "#F8E4E3" :name "Tutu" :shade "Red")
                      (make-ntc--struct :code "#DAC0CD" :name "Twilight" :shade "Violet")
                      (make-ntc--struct :code "#F4F6EC" :name "Twilight Blue" :shade "Grey")
                      (make-ntc--struct :code "#C19156" :name "Twine" :shade "Yellow")
                      (make-ntc--struct :code "#66023C" :name "Tyrian Purple" :shade "Violet")
                      (make-ntc--struct :code "#FF6FFF" :name "Ultra Pink" :shade "Red")
                      (make-ntc--struct :code "#120A8F" :name "Ultramarine" :shade "Blue")
                      (make-ntc--struct :code "#D4574E" :name "Valencia" :shade "Red")
                      (make-ntc--struct :code "#382C38" :name "Valentino" :shade "Violet")
                      (make-ntc--struct :code "#2A2B41" :name "Valhalla" :shade "Violet")
                      (make-ntc--struct :code "#523936" :name "Van Cleef" :shade "Brown")
                      (make-ntc--struct :code "#CCB69B" :name "Vanilla" :shade "Brown")
                      (make-ntc--struct :code "#EBD2D1" :name "Vanilla Ice" :shade "Red")
                      (make-ntc--struct :code "#FDEFD3" :name "Varden" :shade "Yellow")
                      (make-ntc--struct :code "#C80815" :name "Venetian Red" :shade "Red")
                      (make-ntc--struct :code "#2C5778" :name "Venice Blue" :shade "Blue")
                      (make-ntc--struct :code "#8B7D82" :name "Venus" :shade "Violet")
                      (make-ntc--struct :code "#62603E" :name "Verdigris" :shade "Grey")
                      (make-ntc--struct :code "#48531A" :name "Verdun Green" :shade "Green")
                      (make-ntc--struct :code "#FF4D00" :name "Vermilion" :shade "Red")
                      (make-ntc--struct :code "#5C4033" :name "Very Dark Brown" :shade "Brown")
                      (make-ntc--struct :code "#CDCDCD" :name "Very Light Grey" :shade "Grey")
                      (make-ntc--struct :code "#A85533" :name "Vesuvius" :shade "Orange")
                      (make-ntc--struct :code "#564985" :name "Victoria" :shade "Violet")
                      (make-ntc--struct :code "#5F9228" :name "Vida Loca" :shade "Green")
                      (make-ntc--struct :code "#4DB1C8" :name "Viking" :shade "Blue")
                      (make-ntc--struct :code "#955264" :name "Vin Rouge" :shade "Red")
                      (make-ntc--struct :code "#C58F9D" :name "Viola" :shade "Red")
                      (make-ntc--struct :code "#2E2249" :name "Violent Violet" :shade "Violet")
                      (make-ntc--struct :code "#EE82EE" :name "Violet" :shade "Violet")
                      (make-ntc--struct :code "#9F5F9F" :name "Violet Blue" :shade "Violet")
                      (make-ntc--struct :code "#F7468A" :name "Violet Red" :shade "Red")
                      (make-ntc--struct :code "#40826D" :name "Viridian" :shade "Blue")
                      (make-ntc--struct :code "#4B5F56" :name "Viridian Green" :shade "Green")
                      (make-ntc--struct :code "#F9E496" :name "Vis Vis" :shade "Yellow")
                      (make-ntc--struct :code "#97D5B3" :name "Vista Blue" :shade "Green")
                      (make-ntc--struct :code "#E3DFD9" :name "Vista White" :shade "Grey")
                      (make-ntc--struct :code "#FF9980" :name "Vivid Tangerine" :shade "Orange")
                      (make-ntc--struct :code "#803790" :name "Vivid Violet" :shade "Violet")
                      (make-ntc--struct :code "#4E2728" :name "Volcano" :shade "Red")
                      (make-ntc--struct :code "#443240" :name "Voodoo" :shade "Violet")
                      (make-ntc--struct :code "#36383C" :name "Vulcan" :shade "Grey")
                      (make-ntc--struct :code "#D4BBB1" :name "Wafer" :shade "Orange")
                      (make-ntc--struct :code "#5B6E91" :name "Waikawa Grey" :shade "Blue")
                      (make-ntc--struct :code "#4C4E31" :name "Waiouru" :shade "Green")
                      (make-ntc--struct :code "#E4E2DC" :name "Wan White" :shade "Grey")
                      (make-ntc--struct :code "#849137" :name "Wasabi" :shade "Green")
                      (make-ntc--struct :code "#B6ECDE" :name "Water Leaf" :shade "Green")
                      (make-ntc--struct :code "#006E4E" :name "Watercourse" :shade "Green")
                      (make-ntc--struct :code "#D6CA3D" :name "Wattle" :shade "Green")
                      (make-ntc--struct :code "#F2CDBB" :name "Watusi" :shade "Orange")
                      (make-ntc--struct :code "#EEB39E" :name "Wax Flower" :shade "Orange")
                      (make-ntc--struct :code "#FDD7D8" :name "We Peep" :shade "Red")
                      (make-ntc--struct :code "#4C6B88" :name "Wedgewood" :shade "Blue")
                      (make-ntc--struct :code "#8E3537" :name "Well Read" :shade "Red")
                      (make-ntc--struct :code "#5C512F" :name "West Coast" :shade "Yellow")
                      (make-ntc--struct :code "#E5823A" :name "West Side" :shade "Orange")
                      (make-ntc--struct :code "#D4CFC5" :name "Westar" :shade "Grey")
                      (make-ntc--struct :code "#F1919A" :name "Wewak" :shade "Red")
                      (make-ntc--struct :code "#F5DEB3" :name "Wheat" :shade "Brown")
                      (make-ntc--struct :code "#DFD7BD" :name "Wheatfield" :shade "Yellow")
                      (make-ntc--struct :code "#D29062" :name "Whiskey" :shade "Orange")
                      (make-ntc--struct :code "#D4915D" :name "Whiskey Sour" :shade "Orange")
                      (make-ntc--struct :code "#EFE6E6" :name "Whisper" :shade "Grey")
                      (make-ntc--struct :code "#FFFFFF" :name "White" :shade "White")
                      (make-ntc--struct :code "#D7EEE4" :name "White Ice" :shade "Green")
                      (make-ntc--struct :code "#E7E5E8" :name "White Lilac" :shade "Blue")
                      (make-ntc--struct :code "#EEE7DC" :name "White Linen" :shade "Grey")
                      (make-ntc--struct :code "#F8F6D8" :name "White Nectar" :shade "Green")
                      (make-ntc--struct :code "#DAD6CC" :name "White Pointer" :shade "Grey")
                      (make-ntc--struct :code "#D4CFB4" :name "White Rock" :shade "Green")
                      (make-ntc--struct :code "#F5F5F5" :name "White Smoke" :shade "White")
                      (make-ntc--struct :code "#7A89B8" :name "Wild Blue Yonder" :shade "Blue")
                      (make-ntc--struct :code "#E3D474" :name "Wild Rice" :shade "Green")
                      (make-ntc--struct :code "#E7E4DE" :name "Wild Sand" :shade "Grey")
                      (make-ntc--struct :code "#FF3399" :name "Wild Strawberry" :shade "Red")
                      (make-ntc--struct :code "#FD5B78" :name "Wild Watermelon" :shade "Red")
                      (make-ntc--struct :code "#BECA60" :name "Wild Willow" :shade "Green")
                      (make-ntc--struct :code "#53736F" :name "William" :shade "Green")
                      (make-ntc--struct :code "#DFE6CF" :name "Willow Brook" :shade "Green")
                      (make-ntc--struct :code "#69755C" :name "Willow Grove" :shade "Green")
                      (make-ntc--struct :code "#462C77" :name "Windsor" :shade "Violet")
                      (make-ntc--struct :code "#522C35" :name "Wine Berry" :shade "Red")
                      (make-ntc--struct :code "#D0C383" :name "Winter Hazel" :shade "Yellow")
                      (make-ntc--struct :code "#F9E8E2" :name "Wisp Pink" :shade "Red")
                      (make-ntc--struct :code "#C9A0DC" :name "Wisteria" :shade "Violet")
                      (make-ntc--struct :code "#A29ECD" :name "Wistful" :shade "Blue")
                      (make-ntc--struct :code "#FBF073" :name "Witch Haze" :shade "Green")
                      (make-ntc--struct :code "#302621" :name "Wood Bark" :shade "Brown")
                      (make-ntc--struct :code "#463629" :name "Woodburn" :shade "Brown")
                      (make-ntc--struct :code "#626746" :name "Woodland" :shade "Green")
                      (make-ntc--struct :code "#45402B" :name "Woodrush" :shade "Yellow")
                      (make-ntc--struct :code "#2B3230" :name "Woodsmoke" :shade "Grey")
                      (make-ntc--struct :code "#554545" :name "Woody Brown" :shade "Brown")
                      (make-ntc--struct :code "#75876E" :name "Xanadu" :shade "Green")
                      (make-ntc--struct :code "#FFFF00" :name "Yellow" :shade "Yellow")
                      (make-ntc--struct :code "#9ACD32" :name "Yellow Green" :shade "Green")
                      (make-ntc--struct :code "#73633E" :name "Yellow Metal" :shade "Yellow")
                      (make-ntc--struct :code "#FFAE42" :name "Yellow Orange" :shade "Orange")
                      (make-ntc--struct :code "#F49F35" :name "Yellow Sea" :shade "Yellow")
                      (make-ntc--struct :code "#FFC5BB" :name "Your Pink" :shade "Red")
                      (make-ntc--struct :code "#826A21" :name "Yukon Gold" :shade "Yellow")
                      (make-ntc--struct :code "#C7B882" :name "Yuma" :shade "Yellow")
                      (make-ntc--struct :code "#6B5A5A" :name "Zambezi" :shade "Brown")
                      (make-ntc--struct :code "#B2C6B1" :name "Zanah" :shade "Green")
                      (make-ntc--struct :code "#C6723B" :name "Zest" :shade "Orange")
                      (make-ntc--struct :code "#3B3C38" :name "Zeus" :shade "Grey")
                      (make-ntc--struct :code "#81A6AA" :name "Ziggurat" :shade "Blue")
                      (make-ntc--struct :code "#EBC2AF" :name "Zinnwaldite" :shade "Brown")
                      (make-ntc--struct :code "#DEE3E3" :name "Zircon" :shade "Grey")
                      (make-ntc--struct :code "#DDC283" :name "Zombie" :shade "Yellow")
                      (make-ntc--struct :code "#A29589" :name "Zorba" :shade "Brown")
                      (make-ntc--struct :code "#17462E" :name "Zuccini" :shade "Green")
                      (make-ntc--struct :code "#CDD5D5" :name "Zumthor" :shade "Grey")))

(defun ntc--compute-difference (color-code-1 color-code-2)
  "Computes CIEDE2000 difference between two given colors, provided by color.el.

  Colors should be either hex rgb codes or simple HTML color names (recognized
  by color.el).

  More info: https://en.wikipedia.org/wiki/Color_difference"
  (color-cie-de2000 (apply 'color-srgb-to-lab (color-name-to-rgb color-code-1))
                    (apply 'color-srgb-to-lab (color-name-to-rgb color-code-2))))

(defun ntc--format-color-code (color-code)
  "Properly formats the color code: uppercase and with # in front"
  (let ((CODE (upcase color-code)))
    (cond
     ((= (length CODE) 7) CODE)
     ((and (= (length CODE) 6) (string-match-p "^[0-9A-F]+$" CODE)) (concat "#" CODE))
     (t CODE))))


(defun ntc--get-closest-color (color-code)
  "Returns a cons cell containing the matching grade and corresponding
ntc--struct of the closest color"
  (let* ((RGB (ntc--format-color-code color-code))
         (candidate (->> ntc--colors
                         (--annotate (ntc--compute-difference (ntc--struct-code it) RGB))
                         (--sort (< (car it) (car other)))
                         (-first-item))))
    candidate))

(defun ntc-name-this-color (color-code)
  "Returns the name of the color represented by color code or the name of the
closest alternative.

color-code should be a string naming a color (e.g. \"white\") or
a string specifying a color's RGB components (e.g. \"#ff12ec\", \"#fff\")."
  ;; return either the direct match
  (let* ((candidate (ntc--get-closest-color color-code))
         (name (ntc--struct-name (cdr candidate))))
    name))

(defun ntc-shade-this-color (color-code)
  "Returns the shade of the color represented by color code or the shade of the
closest alternative.

  Shade could be one of the following: Red, Orange, Brown, Yellow, Green, Blue,
  Violet, Gray, or White.

  color-code should be a string naming a color (e.g. \"white\") or
  a string specifying a color's RGB components (e.g. \"#ff12ec\", \"#fff\")."
  (let* ((candidate (ntc--get-closest-color color-code))
         (shade (ntc--struct-shade (cdr candidate))))
    shade))

(provide 'name-this-color)

;;; name-this-color.el ends here
